"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .anthropicdocumentsource import (
    AnthropicDocumentSource,
    AnthropicDocumentSourceTypedDict,
)
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import Literal
from typing_extensions import Annotated, TypedDict


class AnthropicDocumentContentTypedDict(TypedDict):
    source: AnthropicDocumentSourceTypedDict
    type: Literal["document"]
    r"""Document content type (PDFs, text files, etc.)"""


class AnthropicDocumentContent(BaseModel):
    source: AnthropicDocumentSource

    TYPE: Annotated[
        Annotated[Literal["document"], AfterValidator(validate_const("document"))],
        pydantic.Field(alias="type"),
    ] = "document"
    r"""Document content type (PDFs, text files, etc.)"""
