"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from r9s.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class RetrieveModelRequestTypedDict(TypedDict):
    model: str
    r"""Model name"""


class RetrieveModelRequest(BaseModel):
    model: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Model name"""
