"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ModelTypedDict(TypedDict):
    id: str
    r"""Model identifier"""
    created: int
    r"""Creation timestamp"""
    owned_by: str
    r"""Model owner"""
    object: Literal["model"]


class Model(BaseModel):
    id: str
    r"""Model identifier"""

    created: int
    r"""Creation timestamp"""

    owned_by: str
    r"""Model owner"""

    OBJECT: Annotated[
        Annotated[Literal["model"], AfterValidator(validate_const("model"))],
        pydantic.Field(alias="object"),
    ] = "model"
