"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .imagegenerationstreamevent import (
    ImageGenerationStreamEvent,
    ImageGenerationStreamEventTypedDict,
)
from r9s.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateImageGenerationResponseBodyTypedDict(TypedDict):
    """SSE stream response wrapper for image generation - the full SSE event structure"""

    data: ImageGenerationStreamEventTypedDict
    r"""Event data payload"""

    id: NotRequired[str]
    r"""SSE event ID"""

    event: NotRequired[str]
    r"""SSE event type"""

    retry: NotRequired[int]
    r"""SSE reconnection time (milliseconds)"""


class CreateImageGenerationResponseBody(BaseModel):
    """SSE stream response wrapper for image generation - the full SSE event structure"""

    data: ImageGenerationStreamEvent
    r"""Event data payload"""

    id: Optional[str] = None
    r"""SSE event ID"""

    event: Optional[str] = None
    r"""SSE event type"""

    retry: Optional[int] = None
    r"""SSE reconnection time (milliseconds)"""
