"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .anthropiccontent import AnthropicContent, AnthropicContentTypedDict
    from .anthropiccontentblockdelta import (
        AnthropicContentBlockDelta,
        AnthropicContentBlockDeltaDelta,
        AnthropicContentBlockDeltaDeltaTypedDict,
        AnthropicContentBlockDeltaType,
        AnthropicContentBlockDeltaTypedDict,
    )
    from .anthropiccontentblockstart import (
        AnthropicContentBlockStart,
        AnthropicContentBlockStartInput,
        AnthropicContentBlockStartInputTypedDict,
        AnthropicContentBlockStartType,
        AnthropicContentBlockStartTypedDict,
        ContentBlock,
        ContentBlockTypedDict,
    )
    from .anthropiccontentblockstop import (
        AnthropicContentBlockStop,
        AnthropicContentBlockStopContentBlock,
        AnthropicContentBlockStopContentBlockTypedDict,
        AnthropicContentBlockStopTypedDict,
    )
    from .anthropicdocumentcontent import (
        AnthropicDocumentContent,
        AnthropicDocumentContentTypedDict,
    )
    from .anthropicdocumentsource import (
        AnthropicDocumentSource,
        AnthropicDocumentSourceTypedDict,
    )
    from .anthropicdocumentsourcebase64 import (
        AnthropicDocumentSourceBase64,
        AnthropicDocumentSourceBase64MediaType,
        AnthropicDocumentSourceBase64TypedDict,
    )
    from .anthropicdocumentsourceurl import (
        AnthropicDocumentSourceURL,
        AnthropicDocumentSourceURLTypedDict,
    )
    from .anthropicimagecontent import (
        AnthropicImageContent,
        AnthropicImageContentTypedDict,
    )
    from .anthropicimagesource import (
        AnthropicImageSource,
        AnthropicImageSourceTypedDict,
    )
    from .anthropicimagesourcebase64 import (
        AnthropicImageSourceBase64,
        AnthropicImageSourceBase64TypedDict,
        MediaType,
    )
    from .anthropicimagesourceurl import (
        AnthropicImageSourceURL,
        AnthropicImageSourceURLTypedDict,
    )
    from .anthropicinputschema import (
        AnthropicInputSchema,
        AnthropicInputSchemaTypedDict,
        Properties,
        PropertiesTypedDict,
    )
    from .anthropicmessagedelta import (
        AnthropicMessageDelta,
        AnthropicMessageDeltaDelta,
        AnthropicMessageDeltaDeltaTypedDict,
        AnthropicMessageDeltaTypedDict,
        AnthropicMessageDeltaUsage,
        AnthropicMessageDeltaUsageTypedDict,
    )
    from .anthropicmessagemessage import (
        AnthropicMessageMessage,
        AnthropicMessageMessageContent,
        AnthropicMessageMessageContentTypedDict,
        AnthropicMessageMessageRole,
        AnthropicMessageMessageTypedDict,
    )
    from .anthropicmessagerequest import (
        AnthropicMessageRequest,
        AnthropicMessageRequest1,
        AnthropicMessageRequest2,
        AnthropicMessageRequest2TypedDict,
        AnthropicMessageRequestServiceTier,
        AnthropicMessageRequestToolChoice,
        AnthropicMessageRequestToolChoiceTypedDict,
        AnthropicMessageRequestType,
        AnthropicMessageRequestTypedDict,
        Thinking,
        ThinkingTypedDict,
    )
    from .anthropicmessageresponse import (
        AnthropicMessageResponse,
        AnthropicMessageResponseTypedDict,
        AnthropicMessageResponseUsage,
        AnthropicMessageResponseUsageTypedDict,
        StopReason,
    )
    from .anthropicmessagestart import (
        AnthropicMessageStart,
        AnthropicMessageStartContent,
        AnthropicMessageStartContentTypedDict,
        AnthropicMessageStartMessage,
        AnthropicMessageStartMessageTypedDict,
        AnthropicMessageStartTypedDict,
        AnthropicMessageStartUsage,
        AnthropicMessageStartUsageTypedDict,
    )
    from .anthropicping import AnthropicPing, AnthropicPingTypedDict
    from .anthropicstreamevent import (
        AnthropicStreamEvent,
        AnthropicStreamEventTypedDict,
    )
    from .anthropicstreammessagestop import (
        AnthropicStreamMessageStop,
        AnthropicStreamMessageStopTypedDict,
    )
    from .anthropictextcontent import (
        AnthropicTextContent,
        AnthropicTextContentTypedDict,
    )
    from .anthropicthinkingcontent import (
        AnthropicThinkingContent,
        AnthropicThinkingContentTypedDict,
    )
    from .anthropictool import AnthropicTool, AnthropicToolTypedDict
    from .anthropictoolcontent import (
        AnthropicToolContent,
        AnthropicToolContentTypedDict,
    )
    from .anthropictoolresultcontent import (
        AnthropicToolResultContent,
        AnthropicToolResultContentTypedDict,
    )
    from .anthropictoolusecontent import (
        AnthropicToolUseContent,
        AnthropicToolUseContentTypedDict,
    )
    from .audio import Audio, AudioTypedDict, Format, Voice
    from .audiospeechrequest import (
        AudioSpeechRequest,
        AudioSpeechRequestResponseFormat,
        AudioSpeechRequestTypedDict,
        AudioSpeechRequestVoice,
    )
    from .audiotranscriptionrequest import (
        AudioTranscriptionRequest,
        AudioTranscriptionRequestResponseFormat,
        AudioTranscriptionRequestTypedDict,
        File,
        FileTypedDict,
        TimestampGranularities,
    )
    from .audiotranscriptionresponse import (
        AudioTranscriptionResponse,
        AudioTranscriptionResponseTypedDict,
        Segments,
        SegmentsTypedDict,
        Words,
        WordsTypedDict,
    )
    from .audiotranslationrequest import (
        AudioTranslationRequest,
        AudioTranslationRequestFile,
        AudioTranslationRequestFileTypedDict,
        AudioTranslationRequestResponseFormat,
        AudioTranslationRequestTypedDict,
    )
    from .audiotranslationresponse import (
        AudioTranslationResponse,
        AudioTranslationResponseTypedDict,
    )
    from .chatcompletionchoice import (
        ChatCompletionChoice,
        ChatCompletionChoiceTypedDict,
        FinishReason,
        Logprobs,
        LogprobsTypedDict,
    )
    from .chatcompletionrequest import (
        ChatCompletionRequest,
        ChatCompletionRequestFunction,
        ChatCompletionRequestFunctionTypedDict,
        ChatCompletionRequestToolChoice,
        ChatCompletionRequestToolChoiceTypedDict,
        ChatCompletionRequestTypedDict,
        Modalities,
        One,
        ReasoningEffort,
        ServiceTier,
        Stop,
        StopTypedDict,
        Two,
        TwoTypedDict,
    )
    from .chatcompletionresponse import (
        ChatCompletionResponse,
        ChatCompletionResponseTypedDict,
    )
    from .chatcompletionstreamchoice import (
        ChatCompletionStreamChoice,
        ChatCompletionStreamChoiceFinishReason,
        ChatCompletionStreamChoiceLogprobs,
        ChatCompletionStreamChoiceLogprobsTypedDict,
        ChatCompletionStreamChoiceTypedDict,
    )
    from .chatcompletionstreamdelta import (
        ChatCompletionStreamDelta,
        ChatCompletionStreamDeltaRole,
        ChatCompletionStreamDeltaTypedDict,
    )
    from .chatcompletionstreamevent import (
        ChatCompletionStreamEvent,
        ChatCompletionStreamEventTypedDict,
    )
    from .completionchoice import (
        CompletionChoice,
        CompletionChoiceFinishReason,
        CompletionChoiceLogprobs,
        CompletionChoiceLogprobsTypedDict,
        CompletionChoiceTypedDict,
    )
    from .completionrequest import (
        CompletionRequest,
        CompletionRequestStop,
        CompletionRequestStopTypedDict,
        CompletionRequestTypedDict,
    )
    from .completionresponse import CompletionResponse, CompletionResponseTypedDict
    from .completionstreamchoice import (
        CompletionStreamChoice,
        CompletionStreamChoiceFinishReason,
        CompletionStreamChoiceLogprobs,
        CompletionStreamChoiceLogprobsTypedDict,
        CompletionStreamChoiceTypedDict,
    )
    from .completionstreamevent import (
        CompletionStreamEvent,
        CompletionStreamEventTypedDict,
    )
    from .createaudiospeechop import (
        CreateAudioSpeechResponse,
        CreateAudioSpeechResponseTypedDict,
    )
    from .createaudiotranscriptionop import (
        CreateAudioTranscriptionResponse,
        CreateAudioTranscriptionResponseTypedDict,
    )
    from .createaudiotranslationop import (
        CreateAudioTranslationResponse,
        CreateAudioTranslationResponseTypedDict,
    )
    from .createchatcompletionop import (
        CreateChatCompletionResponse,
        CreateChatCompletionResponseBody,
        CreateChatCompletionResponseBodyTypedDict,
        CreateChatCompletionResponseTypedDict,
    )
    from .createcompletionop import (
        CreateCompletionResponse,
        CreateCompletionResponseBody,
        CreateCompletionResponseBodyTypedDict,
        CreateCompletionResponseTypedDict,
    )
    from .createengineembeddingop import (
        CreateEngineEmbeddingRequest,
        CreateEngineEmbeddingRequestTypedDict,
    )
    from .createmessageop import (
        CreateMessageResponse,
        CreateMessageResponseBody,
        CreateMessageResponseBodyTypedDict,
        CreateMessageResponseTypedDict,
    )
    from .createproxyrequestop import (
        CreateProxyRequestRequest,
        CreateProxyRequestRequestTypedDict,
    )
    from .createresponseop import (
        CreateResponseResponse,
        CreateResponseResponseBody,
        CreateResponseResponseBodyTypedDict,
        CreateResponseResponseTypedDict,
    )
    from .editchoice import EditChoice, EditChoiceTypedDict
    from .editrequest import EditRequest, EditRequestTypedDict
    from .editresponse import EditResponse, EditResponseTypedDict
    from .embeddingobject import EmbeddingObject, EmbeddingObjectTypedDict
    from .embeddingrequest import (
        EmbeddingRequest,
        EmbeddingRequestInput,
        EmbeddingRequestInputTypedDict,
        EmbeddingRequestTypedDict,
        EncodingFormat,
    )
    from .embeddingresponse import EmbeddingResponse, EmbeddingResponseTypedDict
    from .engineembeddingrequest import (
        EngineEmbeddingRequest,
        EngineEmbeddingRequestEncodingFormat,
        EngineEmbeddingRequestInput,
        EngineEmbeddingRequestInputTypedDict,
        EngineEmbeddingRequestTypedDict,
    )
    from .functioncall import FunctionCall, FunctionCallTypedDict
    from .editimageop import (
        EditImageResponseBody,
        EditImageResponseBodyTypedDict,
        ImageEditEventData,
        ImageEditEventDataTypedDict,
    )
    from .imageeditrequest import (
        ImageEditBackground,
        ImageEditInputFidelity,
        ImageEditModeration,
        ImageEditOutputFormat,
        ImageEditQuality,
        ImageEditRequest,
        ImageEditRequestTypedDict,
        ImageEditResponseFormat,
        ImageEditSize,
        ImageFile,
        ImageFileTypedDict,
    )
    from .imageeditstreamevent import (
        ImageEditStreamEvent,
        ImageEditStreamEventTypedDict,
    )
    from .imagegenerationrequest import (
        ImageGenerationBackground,
        ImageGenerationModeration,
        ImageGenerationOutputFormat,
        ImageGenerationRequest,
        ImageGenerationRequestResponseFormat,
        ImageGenerationRequestTypedDict,
        Quality,
        Size,
        Style,
    )
    from .imagegenerationresponse import (
        ImageGenerationResponse,
        ImageGenerationResponseTypedDict,
        ImageUsage,
        ImageUsageTypedDict,
    )
    from .imagegenerationstreamevent import (
        ImageGenerationStreamData,
        ImageGenerationStreamDataTypedDict,
        ImageGenerationStreamEvent,
        ImageGenerationStreamEventTypedDict,
    )
    from .createimagegenerationop import (
        CreateImageGenerationResponseBody,
        CreateImageGenerationResponseBodyTypedDict,
    )
    from .imageobject import ImageObject, ImageObjectTypedDict
    from .imageurl import Detail, ImageURL, ImageURLTypedDict
    from .jsonschema import JSONSchema, JSONSchemaTypedDict
    from .message import Content, ContentTypedDict, Message, MessageTypedDict, Role
    from .messagecontent import MessageContent, MessageContentTypedDict, Type
    from .model import Model, ModelTypedDict
    from .modellistresponse import ModelListResponse, ModelListResponseTypedDict
    from .moderationcategories import (
        ModerationCategories,
        ModerationCategoriesTypedDict,
    )
    from .moderationcategoryscores import (
        ModerationCategoryScores,
        ModerationCategoryScoresTypedDict,
    )
    from .moderationrequest import (
        ModerationRequest,
        ModerationRequestInput,
        ModerationRequestInputTypedDict,
        ModerationRequestTypedDict,
    )
    from .moderationresponse import ModerationResponse, ModerationResponseTypedDict
    from .moderationresult import ModerationResult, ModerationResultTypedDict
    from .responseformat import (
        ResponseFormat,
        ResponseFormatType,
        ResponseFormatTypedDict,
    )
    from .responseobject import (
        Billing,
        BillingTypedDict,
        Error,
        ErrorTypedDict,
        IncompleteDetails,
        IncompleteDetailsTypedDict,
        Payer,
        ResponseObject,
        ResponseObject1,
        ResponseObject2,
        ResponseObject2TypedDict,
        ResponseObjectEffort,
        ResponseObjectFormat,
        ResponseObjectFormatTypedDict,
        ResponseObjectReasoning,
        ResponseObjectReasoningTypedDict,
        ResponseObjectServiceTier,
        ResponseObjectText,
        ResponseObjectTextTypedDict,
        ResponseObjectToolChoice,
        ResponseObjectToolChoiceTypedDict,
        ResponseObjectTruncation,
        ResponseObjectType,
        ResponseObjectTypedDict,
        ResponseObjectVerbosity,
        Status,
    )
    from .responseoutputitem import (
        ResponseOutputItem,
        ResponseOutputItemContent,
        ResponseOutputItemContentTypedDict,
        ResponseOutputItemRole,
        ResponseOutputItemSchemasType,
        ResponseOutputItemStatus,
        ResponseOutputItemType,
        ResponseOutputItemTypedDict,
        Summary,
        SummaryTypedDict,
    )
    from .responserequest import (
        Effort,
        Input,
        InputTypedDict,
        Reasoning,
        ReasoningTypedDict,
        ResponseRequest,
        ResponseRequest1,
        ResponseRequestFormat,
        ResponseRequestFormatTypedDict,
        ResponseRequestModalities,
        ResponseRequestStop,
        ResponseRequestStopTypedDict,
        ResponseRequestToolChoice,
        ResponseRequestToolChoiceTypedDict,
        ResponseRequestType,
        ResponseRequestTypedDict,
        Text,
        TextTypedDict,
        Truncation,
        Verbosity,
    )
    from .responsestreamevent import (
        Delta,
        DeltaTypedDict,
        ResponseStreamEvent,
        ResponseStreamEvent2,
        ResponseStreamEvent2TypedDict,
        ResponseStreamEventTypedDict,
    )
    from .responsetool import (
        Parameters,
        ParametersTypedDict,
        ResponseTool,
        ResponseToolSchemasType,
        ResponseToolType,
        ResponseToolTypedDict,
    )
    from .responseusage import (
        InputTokensDetails,
        InputTokensDetailsTypedDict,
        OutputTokensDetails,
        OutputTokensDetailsTypedDict,
        ResponseUsage,
        ResponseUsageTypedDict,
    )
    from .retrievemodelop import RetrieveModelRequest, RetrieveModelRequestTypedDict
    from .searchrequest import (
        Engine,
        Extra,
        ExtraTypedDict,
        SearchRequest,
        SearchRequestTypedDict,
    )
    from .searchresponse import (
        SearchResponse,
        SearchResponseEngine,
        SearchResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .streamoptions import StreamOptions, StreamOptionsTypedDict
    from .tool import Function, FunctionTypedDict, Tool, ToolType, ToolTypedDict
    from .toolcall import ToolCall, ToolCallTypedDict
    from .toolchoice import (
        ToolChoice,
        ToolChoiceFunction,
        ToolChoiceFunctionTypedDict,
        ToolChoiceTypedDict,
    )
    from .usage import (
        CompletionTokensDetails,
        CompletionTokensDetailsTypedDict,
        PromptTokensDetails,
        PromptTokensDetailsTypedDict,
        Usage,
        UsageTypedDict,
    )

__all__ = [
    "AnthropicContent",
    "AnthropicContentBlockDelta",
    "AnthropicContentBlockDeltaDelta",
    "AnthropicContentBlockDeltaDeltaTypedDict",
    "AnthropicContentBlockDeltaType",
    "AnthropicContentBlockDeltaTypedDict",
    "AnthropicContentBlockStart",
    "AnthropicContentBlockStartInput",
    "AnthropicContentBlockStartInputTypedDict",
    "AnthropicContentBlockStartType",
    "AnthropicContentBlockStartTypedDict",
    "AnthropicContentBlockStop",
    "AnthropicContentBlockStopContentBlock",
    "AnthropicContentBlockStopContentBlockTypedDict",
    "AnthropicContentBlockStopTypedDict",
    "AnthropicContentTypedDict",
    "AnthropicDocumentContent",
    "AnthropicDocumentContentTypedDict",
    "AnthropicDocumentSource",
    "AnthropicDocumentSourceBase64",
    "AnthropicDocumentSourceBase64MediaType",
    "AnthropicDocumentSourceBase64TypedDict",
    "AnthropicDocumentSourceTypedDict",
    "AnthropicDocumentSourceURL",
    "AnthropicDocumentSourceURLTypedDict",
    "AnthropicImageContent",
    "AnthropicImageContentTypedDict",
    "AnthropicImageSource",
    "AnthropicImageSourceBase64",
    "AnthropicImageSourceBase64TypedDict",
    "AnthropicImageSourceTypedDict",
    "AnthropicImageSourceURL",
    "AnthropicImageSourceURLTypedDict",
    "AnthropicInputSchema",
    "AnthropicInputSchemaTypedDict",
    "AnthropicMessageDelta",
    "AnthropicMessageDeltaDelta",
    "AnthropicMessageDeltaDeltaTypedDict",
    "AnthropicMessageDeltaTypedDict",
    "AnthropicMessageDeltaUsage",
    "AnthropicMessageDeltaUsageTypedDict",
    "AnthropicMessageMessage",
    "AnthropicMessageMessageContent",
    "AnthropicMessageMessageContentTypedDict",
    "AnthropicMessageMessageRole",
    "AnthropicMessageMessageTypedDict",
    "AnthropicMessageRequest",
    "AnthropicMessageRequest1",
    "AnthropicMessageRequest2",
    "AnthropicMessageRequest2TypedDict",
    "AnthropicMessageRequestServiceTier",
    "AnthropicMessageRequestToolChoice",
    "AnthropicMessageRequestToolChoiceTypedDict",
    "AnthropicMessageRequestType",
    "AnthropicMessageRequestTypedDict",
    "AnthropicMessageResponse",
    "AnthropicMessageResponseTypedDict",
    "AnthropicMessageResponseUsage",
    "AnthropicMessageResponseUsageTypedDict",
    "AnthropicMessageStart",
    "AnthropicMessageStartContent",
    "AnthropicMessageStartContentTypedDict",
    "AnthropicMessageStartMessage",
    "AnthropicMessageStartMessageTypedDict",
    "AnthropicMessageStartTypedDict",
    "AnthropicMessageStartUsage",
    "AnthropicMessageStartUsageTypedDict",
    "AnthropicPing",
    "AnthropicPingTypedDict",
    "AnthropicStreamEvent",
    "AnthropicStreamEventTypedDict",
    "AnthropicStreamMessageStop",
    "AnthropicStreamMessageStopTypedDict",
    "AnthropicTextContent",
    "AnthropicTextContentTypedDict",
    "AnthropicThinkingContent",
    "AnthropicThinkingContentTypedDict",
    "AnthropicTool",
    "AnthropicToolContent",
    "AnthropicToolContentTypedDict",
    "AnthropicToolResultContent",
    "AnthropicToolResultContentTypedDict",
    "AnthropicToolTypedDict",
    "AnthropicToolUseContent",
    "AnthropicToolUseContentTypedDict",
    "Audio",
    "AudioSpeechRequest",
    "AudioSpeechRequestResponseFormat",
    "AudioSpeechRequestTypedDict",
    "AudioSpeechRequestVoice",
    "AudioTranscriptionRequest",
    "AudioTranscriptionRequestResponseFormat",
    "AudioTranscriptionRequestTypedDict",
    "AudioTranscriptionResponse",
    "AudioTranscriptionResponseTypedDict",
    "AudioTranslationRequest",
    "AudioTranslationRequestFile",
    "AudioTranslationRequestFileTypedDict",
    "AudioTranslationRequestResponseFormat",
    "AudioTranslationRequestTypedDict",
    "AudioTranslationResponse",
    "AudioTranslationResponseTypedDict",
    "AudioTypedDict",
    "Billing",
    "BillingTypedDict",
    "ChatCompletionChoice",
    "ChatCompletionChoiceTypedDict",
    "ChatCompletionRequest",
    "ChatCompletionRequestFunction",
    "ChatCompletionRequestFunctionTypedDict",
    "ChatCompletionRequestToolChoice",
    "ChatCompletionRequestToolChoiceTypedDict",
    "ChatCompletionRequestTypedDict",
    "ChatCompletionResponse",
    "ChatCompletionResponseTypedDict",
    "ChatCompletionStreamChoice",
    "ChatCompletionStreamChoiceFinishReason",
    "ChatCompletionStreamChoiceLogprobs",
    "ChatCompletionStreamChoiceLogprobsTypedDict",
    "ChatCompletionStreamChoiceTypedDict",
    "ChatCompletionStreamDelta",
    "ChatCompletionStreamDeltaRole",
    "ChatCompletionStreamDeltaTypedDict",
    "ChatCompletionStreamEvent",
    "ChatCompletionStreamEventTypedDict",
    "CompletionChoice",
    "CompletionChoiceFinishReason",
    "CompletionChoiceLogprobs",
    "CompletionChoiceLogprobsTypedDict",
    "CompletionChoiceTypedDict",
    "CompletionRequest",
    "CompletionRequestStop",
    "CompletionRequestStopTypedDict",
    "CompletionRequestTypedDict",
    "CompletionResponse",
    "CompletionResponseTypedDict",
    "CompletionStreamChoice",
    "CompletionStreamChoiceFinishReason",
    "CompletionStreamChoiceLogprobs",
    "CompletionStreamChoiceLogprobsTypedDict",
    "CompletionStreamChoiceTypedDict",
    "CompletionStreamEvent",
    "CompletionStreamEventTypedDict",
    "CompletionTokensDetails",
    "CompletionTokensDetailsTypedDict",
    "Content",
    "ContentBlock",
    "ContentBlockTypedDict",
    "ContentTypedDict",
    "CreateAudioSpeechResponse",
    "CreateAudioSpeechResponseTypedDict",
    "CreateAudioTranscriptionResponse",
    "CreateAudioTranscriptionResponseTypedDict",
    "CreateAudioTranslationResponse",
    "CreateAudioTranslationResponseTypedDict",
    "CreateChatCompletionResponse",
    "CreateChatCompletionResponseBody",
    "CreateChatCompletionResponseBodyTypedDict",
    "CreateChatCompletionResponseTypedDict",
    "CreateCompletionResponse",
    "CreateCompletionResponseBody",
    "CreateCompletionResponseBodyTypedDict",
    "CreateCompletionResponseTypedDict",
    "CreateEngineEmbeddingRequest",
    "CreateEngineEmbeddingRequestTypedDict",
    "CreateMessageResponse",
    "CreateMessageResponseBody",
    "CreateMessageResponseBodyTypedDict",
    "CreateMessageResponseTypedDict",
    "CreateProxyRequestRequest",
    "CreateProxyRequestRequestTypedDict",
    "CreateResponseResponse",
    "CreateResponseResponseBody",
    "CreateResponseResponseBodyTypedDict",
    "CreateResponseResponseTypedDict",
    "Delta",
    "DeltaTypedDict",
    "Detail",
    "EditChoice",
    "EditChoiceTypedDict",
    "EditRequest",
    "EditRequestTypedDict",
    "EditResponse",
    "EditResponseTypedDict",
    "Effort",
    "EmbeddingObject",
    "EmbeddingObjectTypedDict",
    "EmbeddingRequest",
    "EmbeddingRequestInput",
    "EmbeddingRequestInputTypedDict",
    "EmbeddingRequestTypedDict",
    "EmbeddingResponse",
    "EmbeddingResponseTypedDict",
    "EncodingFormat",
    "Engine",
    "EngineEmbeddingRequest",
    "EngineEmbeddingRequestEncodingFormat",
    "EngineEmbeddingRequestInput",
    "EngineEmbeddingRequestInputTypedDict",
    "EngineEmbeddingRequestTypedDict",
    "Error",
    "ErrorTypedDict",
    "Extra",
    "ExtraTypedDict",
    "File",
    "FileTypedDict",
    "FinishReason",
    "Format",
    "Function",
    "FunctionCall",
    "FunctionCallTypedDict",
    "FunctionTypedDict",
    "EditImageResponseBody",
    "EditImageResponseBodyTypedDict",
    "ImageEditEventData",
    "ImageEditEventDataTypedDict",
    "ImageEditBackground",
    "ImageEditInputFidelity",
    "ImageEditModeration",
    "ImageEditOutputFormat",
    "ImageEditQuality",
    "ImageEditRequest",
    "ImageEditRequestTypedDict",
    "ImageEditResponseFormat",
    "ImageEditSize",
    "ImageEditStreamEvent",
    "ImageEditStreamEventTypedDict",
    "ImageFile",
    "ImageFileTypedDict",
    "ImageGenerationBackground",
    "ImageGenerationModeration",
    "ImageGenerationOutputFormat",
    "ImageGenerationRequest",
    "ImageGenerationRequestResponseFormat",
    "ImageGenerationRequestTypedDict",
    "ImageGenerationResponse",
    "ImageGenerationResponseTypedDict",
    "ImageGenerationStreamData",
    "ImageGenerationStreamDataTypedDict",
    "ImageGenerationStreamEvent",
    "ImageGenerationStreamEventTypedDict",
    "CreateImageGenerationResponseBody",
    "CreateImageGenerationResponseBodyTypedDict",
    "ImageUsage",
    "ImageUsageTypedDict",
    "ImageObject",
    "ImageObjectTypedDict",
    "ImageURL",
    "ImageURLTypedDict",
    "IncompleteDetails",
    "IncompleteDetailsTypedDict",
    "Input",
    "InputTokensDetails",
    "InputTokensDetailsTypedDict",
    "InputTypedDict",
    "JSONSchema",
    "JSONSchemaTypedDict",
    "Logprobs",
    "LogprobsTypedDict",
    "MediaType",
    "Message",
    "MessageContent",
    "MessageContentTypedDict",
    "MessageTypedDict",
    "Modalities",
    "Model",
    "ModelListResponse",
    "ModelListResponseTypedDict",
    "ModelTypedDict",
    "ModerationCategories",
    "ModerationCategoriesTypedDict",
    "ModerationCategoryScores",
    "ModerationCategoryScoresTypedDict",
    "ModerationRequest",
    "ModerationRequestInput",
    "ModerationRequestInputTypedDict",
    "ModerationRequestTypedDict",
    "ModerationResponse",
    "ModerationResponseTypedDict",
    "ModerationResult",
    "ModerationResultTypedDict",
    "One",
    "OutputTokensDetails",
    "OutputTokensDetailsTypedDict",
    "Parameters",
    "ParametersTypedDict",
    "Payer",
    "PromptTokensDetails",
    "PromptTokensDetailsTypedDict",
    "Properties",
    "PropertiesTypedDict",
    "Quality",
    "Reasoning",
    "ReasoningEffort",
    "ReasoningTypedDict",
    "ResponseFormat",
    "ResponseFormatType",
    "ResponseFormatTypedDict",
    "ResponseObject",
    "ResponseObject1",
    "ResponseObject2",
    "ResponseObject2TypedDict",
    "ResponseObjectEffort",
    "ResponseObjectFormat",
    "ResponseObjectFormatTypedDict",
    "ResponseObjectReasoning",
    "ResponseObjectReasoningTypedDict",
    "ResponseObjectServiceTier",
    "ResponseObjectText",
    "ResponseObjectTextTypedDict",
    "ResponseObjectToolChoice",
    "ResponseObjectToolChoiceTypedDict",
    "ResponseObjectTruncation",
    "ResponseObjectType",
    "ResponseObjectTypedDict",
    "ResponseObjectVerbosity",
    "ResponseOutputItem",
    "ResponseOutputItemContent",
    "ResponseOutputItemContentTypedDict",
    "ResponseOutputItemRole",
    "ResponseOutputItemSchemasType",
    "ResponseOutputItemStatus",
    "ResponseOutputItemType",
    "ResponseOutputItemTypedDict",
    "ResponseRequest",
    "ResponseRequest1",
    "ResponseRequestFormat",
    "ResponseRequestFormatTypedDict",
    "ResponseRequestModalities",
    "ResponseRequestStop",
    "ResponseRequestStopTypedDict",
    "ResponseRequestToolChoice",
    "ResponseRequestToolChoiceTypedDict",
    "ResponseRequestType",
    "ResponseRequestTypedDict",
    "ResponseStreamEvent",
    "ResponseStreamEvent2",
    "ResponseStreamEvent2TypedDict",
    "ResponseStreamEventTypedDict",
    "ResponseTool",
    "ResponseToolSchemasType",
    "ResponseToolType",
    "ResponseToolTypedDict",
    "ResponseUsage",
    "ResponseUsageTypedDict",
    "RetrieveModelRequest",
    "RetrieveModelRequestTypedDict",
    "Role",
    "SearchRequest",
    "SearchRequestTypedDict",
    "SearchResponse",
    "SearchResponseEngine",
    "SearchResponseTypedDict",
    "Security",
    "SecurityTypedDict",
    "Segments",
    "SegmentsTypedDict",
    "ServiceTier",
    "Size",
    "Status",
    "Stop",
    "StopReason",
    "StopTypedDict",
    "StreamOptions",
    "StreamOptionsTypedDict",
    "Style",
    "Summary",
    "SummaryTypedDict",
    "Text",
    "TextTypedDict",
    "Thinking",
    "ThinkingTypedDict",
    "TimestampGranularities",
    "Tool",
    "ToolCall",
    "ToolCallTypedDict",
    "ToolChoice",
    "ToolChoiceFunction",
    "ToolChoiceFunctionTypedDict",
    "ToolChoiceTypedDict",
    "ToolType",
    "ToolTypedDict",
    "Truncation",
    "Two",
    "TwoTypedDict",
    "Type",
    "Usage",
    "UsageTypedDict",
    "Verbosity",
    "Voice",
    "Words",
    "WordsTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AnthropicContent": ".anthropiccontent",
    "AnthropicContentTypedDict": ".anthropiccontent",
    "AnthropicContentBlockDelta": ".anthropiccontentblockdelta",
    "AnthropicContentBlockDeltaDelta": ".anthropiccontentblockdelta",
    "AnthropicContentBlockDeltaDeltaTypedDict": ".anthropiccontentblockdelta",
    "AnthropicContentBlockDeltaType": ".anthropiccontentblockdelta",
    "AnthropicContentBlockDeltaTypedDict": ".anthropiccontentblockdelta",
    "AnthropicContentBlockStart": ".anthropiccontentblockstart",
    "AnthropicContentBlockStartInput": ".anthropiccontentblockstart",
    "AnthropicContentBlockStartInputTypedDict": ".anthropiccontentblockstart",
    "AnthropicContentBlockStartType": ".anthropiccontentblockstart",
    "AnthropicContentBlockStartTypedDict": ".anthropiccontentblockstart",
    "ContentBlock": ".anthropiccontentblockstart",
    "ContentBlockTypedDict": ".anthropiccontentblockstart",
    "AnthropicContentBlockStop": ".anthropiccontentblockstop",
    "AnthropicContentBlockStopContentBlock": ".anthropiccontentblockstop",
    "AnthropicContentBlockStopContentBlockTypedDict": ".anthropiccontentblockstop",
    "AnthropicContentBlockStopTypedDict": ".anthropiccontentblockstop",
    "AnthropicDocumentContent": ".anthropicdocumentcontent",
    "AnthropicDocumentContentTypedDict": ".anthropicdocumentcontent",
    "AnthropicDocumentSource": ".anthropicdocumentsource",
    "AnthropicDocumentSourceTypedDict": ".anthropicdocumentsource",
    "AnthropicDocumentSourceBase64": ".anthropicdocumentsourcebase64",
    "AnthropicDocumentSourceBase64MediaType": ".anthropicdocumentsourcebase64",
    "AnthropicDocumentSourceBase64TypedDict": ".anthropicdocumentsourcebase64",
    "AnthropicDocumentSourceURL": ".anthropicdocumentsourceurl",
    "AnthropicDocumentSourceURLTypedDict": ".anthropicdocumentsourceurl",
    "AnthropicImageContent": ".anthropicimagecontent",
    "AnthropicImageContentTypedDict": ".anthropicimagecontent",
    "AnthropicImageSource": ".anthropicimagesource",
    "AnthropicImageSourceTypedDict": ".anthropicimagesource",
    "AnthropicImageSourceBase64": ".anthropicimagesourcebase64",
    "AnthropicImageSourceBase64TypedDict": ".anthropicimagesourcebase64",
    "MediaType": ".anthropicimagesourcebase64",
    "AnthropicImageSourceURL": ".anthropicimagesourceurl",
    "AnthropicImageSourceURLTypedDict": ".anthropicimagesourceurl",
    "AnthropicInputSchema": ".anthropicinputschema",
    "AnthropicInputSchemaTypedDict": ".anthropicinputschema",
    "Properties": ".anthropicinputschema",
    "PropertiesTypedDict": ".anthropicinputschema",
    "AnthropicMessageDelta": ".anthropicmessagedelta",
    "AnthropicMessageDeltaDelta": ".anthropicmessagedelta",
    "AnthropicMessageDeltaDeltaTypedDict": ".anthropicmessagedelta",
    "AnthropicMessageDeltaTypedDict": ".anthropicmessagedelta",
    "AnthropicMessageDeltaUsage": ".anthropicmessagedelta",
    "AnthropicMessageDeltaUsageTypedDict": ".anthropicmessagedelta",
    "AnthropicMessageMessage": ".anthropicmessagemessage",
    "AnthropicMessageMessageContent": ".anthropicmessagemessage",
    "AnthropicMessageMessageContentTypedDict": ".anthropicmessagemessage",
    "AnthropicMessageMessageRole": ".anthropicmessagemessage",
    "AnthropicMessageMessageTypedDict": ".anthropicmessagemessage",
    "AnthropicMessageRequest": ".anthropicmessagerequest",
    "AnthropicMessageRequest1": ".anthropicmessagerequest",
    "AnthropicMessageRequest2": ".anthropicmessagerequest",
    "AnthropicMessageRequest2TypedDict": ".anthropicmessagerequest",
    "AnthropicMessageRequestServiceTier": ".anthropicmessagerequest",
    "AnthropicMessageRequestToolChoice": ".anthropicmessagerequest",
    "AnthropicMessageRequestToolChoiceTypedDict": ".anthropicmessagerequest",
    "AnthropicMessageRequestType": ".anthropicmessagerequest",
    "AnthropicMessageRequestTypedDict": ".anthropicmessagerequest",
    "Thinking": ".anthropicmessagerequest",
    "ThinkingTypedDict": ".anthropicmessagerequest",
    "AnthropicMessageResponse": ".anthropicmessageresponse",
    "AnthropicMessageResponseTypedDict": ".anthropicmessageresponse",
    "AnthropicMessageResponseUsage": ".anthropicmessageresponse",
    "AnthropicMessageResponseUsageTypedDict": ".anthropicmessageresponse",
    "StopReason": ".anthropicmessageresponse",
    "AnthropicMessageStart": ".anthropicmessagestart",
    "AnthropicMessageStartContent": ".anthropicmessagestart",
    "AnthropicMessageStartContentTypedDict": ".anthropicmessagestart",
    "AnthropicMessageStartMessage": ".anthropicmessagestart",
    "AnthropicMessageStartMessageTypedDict": ".anthropicmessagestart",
    "AnthropicMessageStartTypedDict": ".anthropicmessagestart",
    "AnthropicMessageStartUsage": ".anthropicmessagestart",
    "AnthropicMessageStartUsageTypedDict": ".anthropicmessagestart",
    "AnthropicPing": ".anthropicping",
    "AnthropicPingTypedDict": ".anthropicping",
    "AnthropicStreamEvent": ".anthropicstreamevent",
    "AnthropicStreamEventTypedDict": ".anthropicstreamevent",
    "AnthropicStreamMessageStop": ".anthropicstreammessagestop",
    "AnthropicStreamMessageStopTypedDict": ".anthropicstreammessagestop",
    "AnthropicTextContent": ".anthropictextcontent",
    "AnthropicTextContentTypedDict": ".anthropictextcontent",
    "AnthropicThinkingContent": ".anthropicthinkingcontent",
    "AnthropicThinkingContentTypedDict": ".anthropicthinkingcontent",
    "AnthropicTool": ".anthropictool",
    "AnthropicToolTypedDict": ".anthropictool",
    "AnthropicToolContent": ".anthropictoolcontent",
    "AnthropicToolContentTypedDict": ".anthropictoolcontent",
    "AnthropicToolResultContent": ".anthropictoolresultcontent",
    "AnthropicToolResultContentTypedDict": ".anthropictoolresultcontent",
    "AnthropicToolUseContent": ".anthropictoolusecontent",
    "AnthropicToolUseContentTypedDict": ".anthropictoolusecontent",
    "Audio": ".audio",
    "AudioTypedDict": ".audio",
    "Format": ".audio",
    "Voice": ".audio",
    "AudioSpeechRequest": ".audiospeechrequest",
    "AudioSpeechRequestResponseFormat": ".audiospeechrequest",
    "AudioSpeechRequestTypedDict": ".audiospeechrequest",
    "AudioSpeechRequestVoice": ".audiospeechrequest",
    "AudioTranscriptionRequest": ".audiotranscriptionrequest",
    "AudioTranscriptionRequestResponseFormat": ".audiotranscriptionrequest",
    "AudioTranscriptionRequestTypedDict": ".audiotranscriptionrequest",
    "File": ".audiotranscriptionrequest",
    "FileTypedDict": ".audiotranscriptionrequest",
    "TimestampGranularities": ".audiotranscriptionrequest",
    "AudioTranscriptionResponse": ".audiotranscriptionresponse",
    "AudioTranscriptionResponseTypedDict": ".audiotranscriptionresponse",
    "Segments": ".audiotranscriptionresponse",
    "SegmentsTypedDict": ".audiotranscriptionresponse",
    "Words": ".audiotranscriptionresponse",
    "WordsTypedDict": ".audiotranscriptionresponse",
    "AudioTranslationRequest": ".audiotranslationrequest",
    "AudioTranslationRequestFile": ".audiotranslationrequest",
    "AudioTranslationRequestFileTypedDict": ".audiotranslationrequest",
    "AudioTranslationRequestResponseFormat": ".audiotranslationrequest",
    "AudioTranslationRequestTypedDict": ".audiotranslationrequest",
    "AudioTranslationResponse": ".audiotranslationresponse",
    "AudioTranslationResponseTypedDict": ".audiotranslationresponse",
    "ChatCompletionChoice": ".chatcompletionchoice",
    "ChatCompletionChoiceTypedDict": ".chatcompletionchoice",
    "FinishReason": ".chatcompletionchoice",
    "Logprobs": ".chatcompletionchoice",
    "LogprobsTypedDict": ".chatcompletionchoice",
    "ChatCompletionRequest": ".chatcompletionrequest",
    "ChatCompletionRequestFunction": ".chatcompletionrequest",
    "ChatCompletionRequestFunctionTypedDict": ".chatcompletionrequest",
    "ChatCompletionRequestToolChoice": ".chatcompletionrequest",
    "ChatCompletionRequestToolChoiceTypedDict": ".chatcompletionrequest",
    "ChatCompletionRequestTypedDict": ".chatcompletionrequest",
    "Modalities": ".chatcompletionrequest",
    "One": ".chatcompletionrequest",
    "ReasoningEffort": ".chatcompletionrequest",
    "ServiceTier": ".chatcompletionrequest",
    "Stop": ".chatcompletionrequest",
    "StopTypedDict": ".chatcompletionrequest",
    "Two": ".chatcompletionrequest",
    "TwoTypedDict": ".chatcompletionrequest",
    "ChatCompletionResponse": ".chatcompletionresponse",
    "ChatCompletionResponseTypedDict": ".chatcompletionresponse",
    "ChatCompletionStreamChoice": ".chatcompletionstreamchoice",
    "ChatCompletionStreamChoiceFinishReason": ".chatcompletionstreamchoice",
    "ChatCompletionStreamChoiceLogprobs": ".chatcompletionstreamchoice",
    "ChatCompletionStreamChoiceLogprobsTypedDict": ".chatcompletionstreamchoice",
    "ChatCompletionStreamChoiceTypedDict": ".chatcompletionstreamchoice",
    "ChatCompletionStreamDelta": ".chatcompletionstreamdelta",
    "ChatCompletionStreamDeltaRole": ".chatcompletionstreamdelta",
    "ChatCompletionStreamDeltaTypedDict": ".chatcompletionstreamdelta",
    "ChatCompletionStreamEvent": ".chatcompletionstreamevent",
    "ChatCompletionStreamEventTypedDict": ".chatcompletionstreamevent",
    "CompletionChoice": ".completionchoice",
    "CompletionChoiceFinishReason": ".completionchoice",
    "CompletionChoiceLogprobs": ".completionchoice",
    "CompletionChoiceLogprobsTypedDict": ".completionchoice",
    "CompletionChoiceTypedDict": ".completionchoice",
    "CompletionRequest": ".completionrequest",
    "CompletionRequestStop": ".completionrequest",
    "CompletionRequestStopTypedDict": ".completionrequest",
    "CompletionRequestTypedDict": ".completionrequest",
    "CompletionResponse": ".completionresponse",
    "CompletionResponseTypedDict": ".completionresponse",
    "CompletionStreamChoice": ".completionstreamchoice",
    "CompletionStreamChoiceFinishReason": ".completionstreamchoice",
    "CompletionStreamChoiceLogprobs": ".completionstreamchoice",
    "CompletionStreamChoiceLogprobsTypedDict": ".completionstreamchoice",
    "CompletionStreamChoiceTypedDict": ".completionstreamchoice",
    "CompletionStreamEvent": ".completionstreamevent",
    "CompletionStreamEventTypedDict": ".completionstreamevent",
    "CreateAudioSpeechResponse": ".createaudiospeechop",
    "CreateAudioSpeechResponseTypedDict": ".createaudiospeechop",
    "CreateAudioTranscriptionResponse": ".createaudiotranscriptionop",
    "CreateAudioTranscriptionResponseTypedDict": ".createaudiotranscriptionop",
    "CreateAudioTranslationResponse": ".createaudiotranslationop",
    "CreateAudioTranslationResponseTypedDict": ".createaudiotranslationop",
    "CreateChatCompletionResponse": ".createchatcompletionop",
    "CreateChatCompletionResponseBody": ".createchatcompletionop",
    "CreateChatCompletionResponseBodyTypedDict": ".createchatcompletionop",
    "CreateChatCompletionResponseTypedDict": ".createchatcompletionop",
    "CreateCompletionResponse": ".createcompletionop",
    "CreateCompletionResponseBody": ".createcompletionop",
    "CreateCompletionResponseBodyTypedDict": ".createcompletionop",
    "CreateCompletionResponseTypedDict": ".createcompletionop",
    "CreateEngineEmbeddingRequest": ".createengineembeddingop",
    "CreateEngineEmbeddingRequestTypedDict": ".createengineembeddingop",
    "CreateMessageResponse": ".createmessageop",
    "CreateMessageResponseBody": ".createmessageop",
    "CreateMessageResponseBodyTypedDict": ".createmessageop",
    "CreateMessageResponseTypedDict": ".createmessageop",
    "CreateProxyRequestRequest": ".createproxyrequestop",
    "CreateProxyRequestRequestTypedDict": ".createproxyrequestop",
    "CreateResponseResponse": ".createresponseop",
    "CreateResponseResponseBody": ".createresponseop",
    "CreateResponseResponseBodyTypedDict": ".createresponseop",
    "CreateResponseResponseTypedDict": ".createresponseop",
    "EditChoice": ".editchoice",
    "EditChoiceTypedDict": ".editchoice",
    "EditRequest": ".editrequest",
    "EditRequestTypedDict": ".editrequest",
    "EditResponse": ".editresponse",
    "EditResponseTypedDict": ".editresponse",
    "EmbeddingObject": ".embeddingobject",
    "EmbeddingObjectTypedDict": ".embeddingobject",
    "EmbeddingRequest": ".embeddingrequest",
    "EmbeddingRequestInput": ".embeddingrequest",
    "EmbeddingRequestInputTypedDict": ".embeddingrequest",
    "EmbeddingRequestTypedDict": ".embeddingrequest",
    "EncodingFormat": ".embeddingrequest",
    "EmbeddingResponse": ".embeddingresponse",
    "EmbeddingResponseTypedDict": ".embeddingresponse",
    "EngineEmbeddingRequest": ".engineembeddingrequest",
    "EngineEmbeddingRequestEncodingFormat": ".engineembeddingrequest",
    "EngineEmbeddingRequestInput": ".engineembeddingrequest",
    "EngineEmbeddingRequestInputTypedDict": ".engineembeddingrequest",
    "EngineEmbeddingRequestTypedDict": ".engineembeddingrequest",
    "FunctionCall": ".functioncall",
    "FunctionCallTypedDict": ".functioncall",
    "EditImageResponseBody": ".editimageop",
    "EditImageResponseBodyTypedDict": ".editimageop",
    "ImageEditEventData": ".editimageop",
    "ImageEditEventDataTypedDict": ".editimageop",
    "ImageEditBackground": ".imageeditrequest",
    "ImageEditInputFidelity": ".imageeditrequest",
    "ImageEditModeration": ".imageeditrequest",
    "ImageEditOutputFormat": ".imageeditrequest",
    "ImageEditQuality": ".imageeditrequest",
    "ImageEditRequest": ".imageeditrequest",
    "ImageEditRequestTypedDict": ".imageeditrequest",
    "ImageEditResponseFormat": ".imageeditrequest",
    "ImageEditSize": ".imageeditrequest",
    "ImageEditStreamEvent": ".imageeditstreamevent",
    "ImageEditStreamEventTypedDict": ".imageeditstreamevent",
    "ImageFile": ".imageeditrequest",
    "ImageFileTypedDict": ".imageeditrequest",
    "ImageGenerationBackground": ".imagegenerationrequest",
    "ImageGenerationModeration": ".imagegenerationrequest",
    "ImageGenerationOutputFormat": ".imagegenerationrequest",
    "ImageGenerationRequest": ".imagegenerationrequest",
    "ImageGenerationRequestResponseFormat": ".imagegenerationrequest",
    "ImageGenerationRequestTypedDict": ".imagegenerationrequest",
    "Quality": ".imagegenerationrequest",
    "Size": ".imagegenerationrequest",
    "Style": ".imagegenerationrequest",
    "ImageGenerationResponse": ".imagegenerationresponse",
    "ImageGenerationResponseTypedDict": ".imagegenerationresponse",
    "ImageGenerationStreamData": ".imagegenerationstreamevent",
    "ImageGenerationStreamDataTypedDict": ".imagegenerationstreamevent",
    "ImageGenerationStreamEvent": ".imagegenerationstreamevent",
    "ImageGenerationStreamEventTypedDict": ".imagegenerationstreamevent",
    "CreateImageGenerationResponseBody": ".createimagegenerationop",
    "CreateImageGenerationResponseBodyTypedDict": ".createimagegenerationop",
    "ImageUsage": ".imagegenerationresponse",
    "ImageUsageTypedDict": ".imagegenerationresponse",
    "ImageObject": ".imageobject",
    "ImageObjectTypedDict": ".imageobject",
    "Detail": ".imageurl",
    "ImageURL": ".imageurl",
    "ImageURLTypedDict": ".imageurl",
    "JSONSchema": ".jsonschema",
    "JSONSchemaTypedDict": ".jsonschema",
    "Content": ".message",
    "ContentTypedDict": ".message",
    "Message": ".message",
    "MessageTypedDict": ".message",
    "Role": ".message",
    "MessageContent": ".messagecontent",
    "MessageContentTypedDict": ".messagecontent",
    "Type": ".messagecontent",
    "Model": ".model",
    "ModelTypedDict": ".model",
    "ModelListResponse": ".modellistresponse",
    "ModelListResponseTypedDict": ".modellistresponse",
    "ModerationCategories": ".moderationcategories",
    "ModerationCategoriesTypedDict": ".moderationcategories",
    "ModerationCategoryScores": ".moderationcategoryscores",
    "ModerationCategoryScoresTypedDict": ".moderationcategoryscores",
    "ModerationRequest": ".moderationrequest",
    "ModerationRequestInput": ".moderationrequest",
    "ModerationRequestInputTypedDict": ".moderationrequest",
    "ModerationRequestTypedDict": ".moderationrequest",
    "ModerationResponse": ".moderationresponse",
    "ModerationResponseTypedDict": ".moderationresponse",
    "ModerationResult": ".moderationresult",
    "ModerationResultTypedDict": ".moderationresult",
    "ResponseFormat": ".responseformat",
    "ResponseFormatType": ".responseformat",
    "ResponseFormatTypedDict": ".responseformat",
    "Billing": ".responseobject",
    "BillingTypedDict": ".responseobject",
    "Error": ".responseobject",
    "ErrorTypedDict": ".responseobject",
    "IncompleteDetails": ".responseobject",
    "IncompleteDetailsTypedDict": ".responseobject",
    "Payer": ".responseobject",
    "ResponseObject": ".responseobject",
    "ResponseObject1": ".responseobject",
    "ResponseObject2": ".responseobject",
    "ResponseObject2TypedDict": ".responseobject",
    "ResponseObjectEffort": ".responseobject",
    "ResponseObjectFormat": ".responseobject",
    "ResponseObjectFormatTypedDict": ".responseobject",
    "ResponseObjectReasoning": ".responseobject",
    "ResponseObjectReasoningTypedDict": ".responseobject",
    "ResponseObjectServiceTier": ".responseobject",
    "ResponseObjectText": ".responseobject",
    "ResponseObjectTextTypedDict": ".responseobject",
    "ResponseObjectToolChoice": ".responseobject",
    "ResponseObjectToolChoiceTypedDict": ".responseobject",
    "ResponseObjectTruncation": ".responseobject",
    "ResponseObjectType": ".responseobject",
    "ResponseObjectTypedDict": ".responseobject",
    "ResponseObjectVerbosity": ".responseobject",
    "Status": ".responseobject",
    "ResponseOutputItem": ".responseoutputitem",
    "ResponseOutputItemContent": ".responseoutputitem",
    "ResponseOutputItemContentTypedDict": ".responseoutputitem",
    "ResponseOutputItemRole": ".responseoutputitem",
    "ResponseOutputItemSchemasType": ".responseoutputitem",
    "ResponseOutputItemStatus": ".responseoutputitem",
    "ResponseOutputItemType": ".responseoutputitem",
    "ResponseOutputItemTypedDict": ".responseoutputitem",
    "Summary": ".responseoutputitem",
    "SummaryTypedDict": ".responseoutputitem",
    "Effort": ".responserequest",
    "Input": ".responserequest",
    "InputTypedDict": ".responserequest",
    "Reasoning": ".responserequest",
    "ReasoningTypedDict": ".responserequest",
    "ResponseRequest": ".responserequest",
    "ResponseRequest1": ".responserequest",
    "ResponseRequestFormat": ".responserequest",
    "ResponseRequestFormatTypedDict": ".responserequest",
    "ResponseRequestModalities": ".responserequest",
    "ResponseRequestStop": ".responserequest",
    "ResponseRequestStopTypedDict": ".responserequest",
    "ResponseRequestToolChoice": ".responserequest",
    "ResponseRequestToolChoiceTypedDict": ".responserequest",
    "ResponseRequestType": ".responserequest",
    "ResponseRequestTypedDict": ".responserequest",
    "Text": ".responserequest",
    "TextTypedDict": ".responserequest",
    "Truncation": ".responserequest",
    "Verbosity": ".responserequest",
    "Delta": ".responsestreamevent",
    "DeltaTypedDict": ".responsestreamevent",
    "ResponseStreamEvent": ".responsestreamevent",
    "ResponseStreamEvent2": ".responsestreamevent",
    "ResponseStreamEvent2TypedDict": ".responsestreamevent",
    "ResponseStreamEventTypedDict": ".responsestreamevent",
    "Parameters": ".responsetool",
    "ParametersTypedDict": ".responsetool",
    "ResponseTool": ".responsetool",
    "ResponseToolSchemasType": ".responsetool",
    "ResponseToolType": ".responsetool",
    "ResponseToolTypedDict": ".responsetool",
    "InputTokensDetails": ".responseusage",
    "InputTokensDetailsTypedDict": ".responseusage",
    "OutputTokensDetails": ".responseusage",
    "OutputTokensDetailsTypedDict": ".responseusage",
    "ResponseUsage": ".responseusage",
    "ResponseUsageTypedDict": ".responseusage",
    "RetrieveModelRequest": ".retrievemodelop",
    "RetrieveModelRequestTypedDict": ".retrievemodelop",
    "Engine": ".searchrequest",
    "Extra": ".searchrequest",
    "ExtraTypedDict": ".searchrequest",
    "SearchRequest": ".searchrequest",
    "SearchRequestTypedDict": ".searchrequest",
    "SearchResponse": ".searchresponse",
    "SearchResponseEngine": ".searchresponse",
    "SearchResponseTypedDict": ".searchresponse",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "StreamOptions": ".streamoptions",
    "StreamOptionsTypedDict": ".streamoptions",
    "Function": ".tool",
    "FunctionTypedDict": ".tool",
    "Tool": ".tool",
    "ToolType": ".tool",
    "ToolTypedDict": ".tool",
    "ToolCall": ".toolcall",
    "ToolCallTypedDict": ".toolcall",
    "ToolChoice": ".toolchoice",
    "ToolChoiceFunction": ".toolchoice",
    "ToolChoiceFunctionTypedDict": ".toolchoice",
    "ToolChoiceTypedDict": ".toolchoice",
    "CompletionTokensDetails": ".usage",
    "CompletionTokensDetailsTypedDict": ".usage",
    "PromptTokensDetails": ".usage",
    "PromptTokensDetailsTypedDict": ".usage",
    "Usage": ".usage",
    "UsageTypedDict": ".usage",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
