"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class EmbeddingObjectTypedDict(TypedDict):
    embedding: List[float]
    r"""Embedding vector"""
    index: int
    object: Literal["embedding"]


class EmbeddingObject(BaseModel):
    embedding: List[float]
    r"""Embedding vector"""

    index: int

    OBJECT: Annotated[
        Annotated[Literal["embedding"], AfterValidator(validate_const("embedding"))],
        pydantic.Field(alias="object"),
    ] = "embedding"
