"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from typing import Union
from typing_extensions import TypeAliasType


CreateAudioSpeechResponseTypedDict = TypeAliasType(
    "CreateAudioSpeechResponseTypedDict",
    Union[
        httpx.Response,
        httpx.Response,
        httpx.Response,
        httpx.Response,
        httpx.Response,
        httpx.Response,
    ],
)


CreateAudioSpeechResponse = TypeAliasType(
    "CreateAudioSpeechResponse",
    Union[
        httpx.Response,
        httpx.Response,
        httpx.Response,
        httpx.Response,
        httpx.Response,
        httpx.Response,
    ],
)
