"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from typing_extensions import TypedDict


class EditChoiceTypedDict(TypedDict):
    text: str
    index: int


class EditChoice(BaseModel):
    text: str

    index: int
