"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from enum import Enum
from r9s import errors, models, utils
from r9s._hooks import HookContext
from r9s.types import OptionalNullable, UNSET
from r9s.utils import eventstreaming
from r9s.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Dict, List, Literal, Mapping, Optional, Union, overload


class CreateAcceptEnum(str, Enum):
    APPLICATION_JSON = "application/json"
    TEXT_EVENT_STREAM = "text/event-stream"


class Chat(BaseSDK):
    @overload
    def create(
        self,
        *,
        model: str,
        messages: Union[List[models.Message], List[models.MessageTypedDict]],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, float]] = None,
        logprobs: Optional[bool] = None,
        top_logprobs: Optional[int] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        modalities: Optional[List[models.Modalities]] = None,
        audio: Optional[Union[models.Audio, models.AudioTypedDict]] = None,
        presence_penalty: Optional[float] = None,
        response_format: Optional[
            Union[models.ResponseFormat, models.ResponseFormatTypedDict]
        ] = None,
        seed: Optional[int] = None,
        service_tier: Optional[models.ServiceTier] = None,
        stop: Optional[Union[models.Stop, models.StopTypedDict]] = None,
        stream: Union[Literal[False], None] = None,
        stream_options: Optional[
            Union[models.StreamOptions, models.StreamOptionsTypedDict]
        ] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[Union[List[models.Tool], List[models.ToolTypedDict]]] = None,
        tool_choice: Optional[
            Union[
                models.ChatCompletionRequestToolChoice,
                models.ChatCompletionRequestToolChoiceTypedDict,
            ]
        ] = None,
        parallel_tool_calls: Optional[bool] = None,
        user: Optional[str] = None,
        reasoning_effort: Optional[models.ReasoningEffort] = None,
        max_completion_tokens: Optional[int] = None,
        store: Optional[bool] = None,
        metadata: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ChatCompletionResponse:
        r"""Create chat completion

        Create a chat completion, supports streaming

        :param model: Model name
        :param messages: Messages list
        :param frequency_penalty:
        :param logit_bias:
        :param logprobs: When true, stream must be false (OpenAI constraint)
        :param top_logprobs:
        :param max_tokens:
        :param n: Number of chat completion choices to generate
        :param modalities: Output modality types. Use [\"text\", \"audio\"] for audio output
        :param audio:
        :param presence_penalty:
        :param response_format:
        :param seed:
        :param service_tier:
        :param stop:
        :param stream:
        :param stream_options:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter (non-OpenAI standard, model-specific)
        :param tools:
        :param tool_choice:
        :param parallel_tool_calls: Whether to enable parallel function calling during tool use. Only valid when tools are specified.
        :param user: Unique identifier representing end-user for abuse monitoring
        :param reasoning_effort: Reasoning effort level for o1 series models (low, medium, high)
        :param max_completion_tokens: Maximum number of tokens to generate in the completion (alternative to max_tokens, more precise)
        :param store: Whether to store the output for use in model distillation or evals
        :param metadata: Custom metadata to attach to the request for tracking purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    @overload
    def create(
        self,
        *,
        model: str,
        messages: Union[List[models.Message], List[models.MessageTypedDict]],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, float]] = None,
        logprobs: Optional[bool] = None,
        top_logprobs: Optional[int] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        modalities: Optional[List[models.Modalities]] = None,
        audio: Optional[Union[models.Audio, models.AudioTypedDict]] = None,
        presence_penalty: Optional[float] = None,
        response_format: Optional[
            Union[models.ResponseFormat, models.ResponseFormatTypedDict]
        ] = None,
        seed: Optional[int] = None,
        service_tier: Optional[models.ServiceTier] = None,
        stop: Optional[Union[models.Stop, models.StopTypedDict]] = None,
        stream: Literal[True],
        stream_options: Optional[
            Union[models.StreamOptions, models.StreamOptionsTypedDict]
        ] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[Union[List[models.Tool], List[models.ToolTypedDict]]] = None,
        tool_choice: Optional[
            Union[
                models.ChatCompletionRequestToolChoice,
                models.ChatCompletionRequestToolChoiceTypedDict,
            ]
        ] = None,
        parallel_tool_calls: Optional[bool] = None,
        user: Optional[str] = None,
        reasoning_effort: Optional[models.ReasoningEffort] = None,
        max_completion_tokens: Optional[int] = None,
        store: Optional[bool] = None,
        metadata: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStream[models.ChatCompletionStreamEvent]:
        r"""Create chat completion

        Create a chat completion, supports streaming

        :param model: Model name
        :param messages: Messages list
        :param frequency_penalty:
        :param logit_bias:
        :param logprobs: When true, stream must be false (OpenAI constraint)
        :param top_logprobs:
        :param max_tokens:
        :param n: Number of chat completion choices to generate
        :param modalities: Output modality types. Use [\"text\", \"audio\"] for audio output
        :param audio:
        :param presence_penalty:
        :param response_format:
        :param seed:
        :param service_tier:
        :param stop:
        :param stream:
        :param stream_options:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter (non-OpenAI standard, model-specific)
        :param tools:
        :param tool_choice:
        :param parallel_tool_calls: Whether to enable parallel function calling during tool use. Only valid when tools are specified.
        :param user: Unique identifier representing end-user for abuse monitoring
        :param reasoning_effort: Reasoning effort level for o1 series models (low, medium, high)
        :param max_completion_tokens: Maximum number of tokens to generate in the completion (alternative to max_tokens, more precise)
        :param store: Whether to store the output for use in model distillation or evals
        :param metadata: Custom metadata to attach to the request for tracking purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    def create(
        self,
        *,
        model: str,
        messages: Union[List[models.Message], List[models.MessageTypedDict]],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, float]] = None,
        logprobs: Optional[bool] = None,
        top_logprobs: Optional[int] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        modalities: Optional[List[models.Modalities]] = None,
        audio: Optional[Union[models.Audio, models.AudioTypedDict]] = None,
        presence_penalty: Optional[float] = None,
        response_format: Optional[
            Union[models.ResponseFormat, models.ResponseFormatTypedDict]
        ] = None,
        seed: Optional[int] = None,
        service_tier: Optional[models.ServiceTier] = None,
        stop: Optional[Union[models.Stop, models.StopTypedDict]] = None,
        stream: Optional[bool] = False,
        stream_options: Optional[
            Union[models.StreamOptions, models.StreamOptionsTypedDict]
        ] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[Union[List[models.Tool], List[models.ToolTypedDict]]] = None,
        tool_choice: Optional[
            Union[
                models.ChatCompletionRequestToolChoice,
                models.ChatCompletionRequestToolChoiceTypedDict,
            ]
        ] = None,
        parallel_tool_calls: Optional[bool] = None,
        user: Optional[str] = None,
        reasoning_effort: Optional[models.ReasoningEffort] = None,
        max_completion_tokens: Optional[int] = None,
        store: Optional[bool] = None,
        metadata: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateChatCompletionResponse:
        r"""Create chat completion

        Create a chat completion, supports streaming

        :param model: Model name
        :param messages: Messages list
        :param frequency_penalty:
        :param logit_bias:
        :param logprobs: When true, stream must be false (OpenAI constraint)
        :param top_logprobs:
        :param max_tokens:
        :param n: Number of chat completion choices to generate
        :param modalities: Output modality types. Use [\"text\", \"audio\"] for audio output
        :param audio:
        :param presence_penalty:
        :param response_format:
        :param seed:
        :param service_tier:
        :param stop:
        :param stream:
        :param stream_options:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter (non-OpenAI standard, model-specific)
        :param tools:
        :param tool_choice:
        :param parallel_tool_calls: Whether to enable parallel function calling during tool use. Only valid when tools are specified.
        :param user: Unique identifier representing end-user for abuse monitoring
        :param reasoning_effort: Reasoning effort level for o1 series models (low, medium, high)
        :param max_completion_tokens: Maximum number of tokens to generate in the completion (alternative to max_tokens, more precise)
        :param store: Whether to store the output for use in model distillation or evals
        :param metadata: Custom metadata to attach to the request for tracking purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ChatCompletionRequest(
            model=model,
            messages=utils.get_pydantic_model(messages, List[models.Message]),
            frequency_penalty=frequency_penalty,
            logit_bias=logit_bias,
            logprobs=logprobs,
            top_logprobs=top_logprobs,
            max_tokens=max_tokens,
            n=n,
            modalities=modalities,
            audio=utils.get_pydantic_model(audio, Optional[models.Audio]),
            presence_penalty=presence_penalty,
            response_format=utils.get_pydantic_model(
                response_format, Optional[models.ResponseFormat]
            ),
            seed=seed,
            service_tier=service_tier,
            stop=stop,
            stream=stream,
            stream_options=utils.get_pydantic_model(
                stream_options, Optional[models.StreamOptions]
            ),
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            tools=utils.get_pydantic_model(tools, Optional[List[models.Tool]]),
            tool_choice=utils.get_pydantic_model(
                tool_choice, Optional[models.ChatCompletionRequestToolChoice]
            ),
            parallel_tool_calls=parallel_tool_calls,
            user=user,
            reasoning_effort=reasoning_effort,
            max_completion_tokens=max_completion_tokens,
            store=store,
            metadata=metadata,
        )

        req = self._build_request(
            method="POST",
            path="/chat/completions",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream" if stream else "application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ChatCompletionRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createChatCompletion",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            return unmarshal_json_response(
                models.ChatCompletionResponse, http_res, http_res_text
            )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStream(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.CreateChatCompletionResponseBody
                ).data,
                sentinel="[DONE]",
                client_ref=self,
            )
        if utils.match_response(http_res, "400", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res, http_res_text
            )
            raise errors.BadRequestError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "401", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.AuthenticationErrorData, http_res, http_res_text
            )
            raise errors.AuthenticationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "403", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.PermissionDeniedErrorData, http_res, http_res_text
            )
            raise errors.PermissionDeniedError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res, http_res_text
            )
            raise errors.UnprocessableEntityError(
                response_data, http_res, http_res_text
            )
        if utils.match_response(http_res, "429", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.RateLimitErrorData, http_res, http_res_text
            )
            raise errors.RateLimitError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "500", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res, http_res_text
            )
            raise errors.InternalServerError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "503", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res, http_res_text
            )
            raise errors.ServiceUnavailableError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)

        http_res_text = utils.stream_to_text(http_res)
        raise errors.R9SDefaultError(
            "Unexpected response received", http_res, http_res_text
        )

    @overload
    async def create_async(
        self,
        *,
        model: str,
        messages: Union[List[models.Message], List[models.MessageTypedDict]],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, float]] = None,
        logprobs: Optional[bool] = None,
        top_logprobs: Optional[int] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        modalities: Optional[List[models.Modalities]] = None,
        audio: Optional[Union[models.Audio, models.AudioTypedDict]] = None,
        presence_penalty: Optional[float] = None,
        response_format: Optional[
            Union[models.ResponseFormat, models.ResponseFormatTypedDict]
        ] = None,
        seed: Optional[int] = None,
        service_tier: Optional[models.ServiceTier] = None,
        stop: Optional[Union[models.Stop, models.StopTypedDict]] = None,
        stream: Union[Literal[False], None] = None,
        stream_options: Optional[
            Union[models.StreamOptions, models.StreamOptionsTypedDict]
        ] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[Union[List[models.Tool], List[models.ToolTypedDict]]] = None,
        tool_choice: Optional[
            Union[
                models.ChatCompletionRequestToolChoice,
                models.ChatCompletionRequestToolChoiceTypedDict,
            ]
        ] = None,
        parallel_tool_calls: Optional[bool] = None,
        user: Optional[str] = None,
        reasoning_effort: Optional[models.ReasoningEffort] = None,
        max_completion_tokens: Optional[int] = None,
        store: Optional[bool] = None,
        metadata: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ChatCompletionResponse:
        r"""Create chat completion

        Create a chat completion, supports streaming

        :param model: Model name
        :param messages: Messages list
        :param frequency_penalty:
        :param logit_bias:
        :param logprobs: When true, stream must be false (OpenAI constraint)
        :param top_logprobs:
        :param max_tokens:
        :param n: Number of chat completion choices to generate
        :param modalities: Output modality types. Use [\"text\", \"audio\"] for audio output
        :param audio:
        :param presence_penalty:
        :param response_format:
        :param seed:
        :param service_tier:
        :param stop:
        :param stream:
        :param stream_options:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter (non-OpenAI standard, model-specific)
        :param tools:
        :param tool_choice:
        :param parallel_tool_calls: Whether to enable parallel function calling during tool use. Only valid when tools are specified.
        :param user: Unique identifier representing end-user for abuse monitoring
        :param reasoning_effort: Reasoning effort level for o1 series models (low, medium, high)
        :param max_completion_tokens: Maximum number of tokens to generate in the completion (alternative to max_tokens, more precise)
        :param store: Whether to store the output for use in model distillation or evals
        :param metadata: Custom metadata to attach to the request for tracking purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    @overload
    async def create_async(
        self,
        *,
        model: str,
        messages: Union[List[models.Message], List[models.MessageTypedDict]],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, float]] = None,
        logprobs: Optional[bool] = None,
        top_logprobs: Optional[int] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        modalities: Optional[List[models.Modalities]] = None,
        audio: Optional[Union[models.Audio, models.AudioTypedDict]] = None,
        presence_penalty: Optional[float] = None,
        response_format: Optional[
            Union[models.ResponseFormat, models.ResponseFormatTypedDict]
        ] = None,
        seed: Optional[int] = None,
        service_tier: Optional[models.ServiceTier] = None,
        stop: Optional[Union[models.Stop, models.StopTypedDict]] = None,
        stream: Literal[True],
        stream_options: Optional[
            Union[models.StreamOptions, models.StreamOptionsTypedDict]
        ] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[Union[List[models.Tool], List[models.ToolTypedDict]]] = None,
        tool_choice: Optional[
            Union[
                models.ChatCompletionRequestToolChoice,
                models.ChatCompletionRequestToolChoiceTypedDict,
            ]
        ] = None,
        parallel_tool_calls: Optional[bool] = None,
        user: Optional[str] = None,
        reasoning_effort: Optional[models.ReasoningEffort] = None,
        max_completion_tokens: Optional[int] = None,
        store: Optional[bool] = None,
        metadata: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStreamAsync[models.ChatCompletionStreamEvent]:
        r"""Create chat completion

        Create a chat completion, supports streaming

        :param model: Model name
        :param messages: Messages list
        :param frequency_penalty:
        :param logit_bias:
        :param logprobs: When true, stream must be false (OpenAI constraint)
        :param top_logprobs:
        :param max_tokens:
        :param n: Number of chat completion choices to generate
        :param modalities: Output modality types. Use [\"text\", \"audio\"] for audio output
        :param audio:
        :param presence_penalty:
        :param response_format:
        :param seed:
        :param service_tier:
        :param stop:
        :param stream:
        :param stream_options:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter (non-OpenAI standard, model-specific)
        :param tools:
        :param tool_choice:
        :param parallel_tool_calls: Whether to enable parallel function calling during tool use. Only valid when tools are specified.
        :param user: Unique identifier representing end-user for abuse monitoring
        :param reasoning_effort: Reasoning effort level for o1 series models (low, medium, high)
        :param max_completion_tokens: Maximum number of tokens to generate in the completion (alternative to max_tokens, more precise)
        :param store: Whether to store the output for use in model distillation or evals
        :param metadata: Custom metadata to attach to the request for tracking purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    async def create_async(
        self,
        *,
        model: str,
        messages: Union[List[models.Message], List[models.MessageTypedDict]],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, float]] = None,
        logprobs: Optional[bool] = None,
        top_logprobs: Optional[int] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        modalities: Optional[List[models.Modalities]] = None,
        audio: Optional[Union[models.Audio, models.AudioTypedDict]] = None,
        presence_penalty: Optional[float] = None,
        response_format: Optional[
            Union[models.ResponseFormat, models.ResponseFormatTypedDict]
        ] = None,
        seed: Optional[int] = None,
        service_tier: Optional[models.ServiceTier] = None,
        stop: Optional[Union[models.Stop, models.StopTypedDict]] = None,
        stream: Optional[bool] = False,
        stream_options: Optional[
            Union[models.StreamOptions, models.StreamOptionsTypedDict]
        ] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[Union[List[models.Tool], List[models.ToolTypedDict]]] = None,
        tool_choice: Optional[
            Union[
                models.ChatCompletionRequestToolChoice,
                models.ChatCompletionRequestToolChoiceTypedDict,
            ]
        ] = None,
        parallel_tool_calls: Optional[bool] = None,
        user: Optional[str] = None,
        reasoning_effort: Optional[models.ReasoningEffort] = None,
        max_completion_tokens: Optional[int] = None,
        store: Optional[bool] = None,
        metadata: Optional[Dict[str, Any]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateChatCompletionResponse:
        r"""Create chat completion

        Create a chat completion, supports streaming

        :param model: Model name
        :param messages: Messages list
        :param frequency_penalty:
        :param logit_bias:
        :param logprobs: When true, stream must be false (OpenAI constraint)
        :param top_logprobs:
        :param max_tokens:
        :param n: Number of chat completion choices to generate
        :param modalities: Output modality types. Use [\"text\", \"audio\"] for audio output
        :param audio:
        :param presence_penalty:
        :param response_format:
        :param seed:
        :param service_tier:
        :param stop:
        :param stream:
        :param stream_options:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter (non-OpenAI standard, model-specific)
        :param tools:
        :param tool_choice:
        :param parallel_tool_calls: Whether to enable parallel function calling during tool use. Only valid when tools are specified.
        :param user: Unique identifier representing end-user for abuse monitoring
        :param reasoning_effort: Reasoning effort level for o1 series models (low, medium, high)
        :param max_completion_tokens: Maximum number of tokens to generate in the completion (alternative to max_tokens, more precise)
        :param store: Whether to store the output for use in model distillation or evals
        :param metadata: Custom metadata to attach to the request for tracking purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ChatCompletionRequest(
            model=model,
            messages=utils.get_pydantic_model(messages, List[models.Message]),
            frequency_penalty=frequency_penalty,
            logit_bias=logit_bias,
            logprobs=logprobs,
            top_logprobs=top_logprobs,
            max_tokens=max_tokens,
            n=n,
            modalities=modalities,
            audio=utils.get_pydantic_model(audio, Optional[models.Audio]),
            presence_penalty=presence_penalty,
            response_format=utils.get_pydantic_model(
                response_format, Optional[models.ResponseFormat]
            ),
            seed=seed,
            service_tier=service_tier,
            stop=stop,
            stream=stream,
            stream_options=utils.get_pydantic_model(
                stream_options, Optional[models.StreamOptions]
            ),
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            tools=utils.get_pydantic_model(tools, Optional[List[models.Tool]]),
            tool_choice=utils.get_pydantic_model(
                tool_choice, Optional[models.ChatCompletionRequestToolChoice]
            ),
            parallel_tool_calls=parallel_tool_calls,
            user=user,
            reasoning_effort=reasoning_effort,
            max_completion_tokens=max_completion_tokens,
            store=store,
            metadata=metadata,
        )

        req = self._build_request_async(
            method="POST",
            path="/chat/completions",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream" if stream else "application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ChatCompletionRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createChatCompletion",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            return unmarshal_json_response(
                models.ChatCompletionResponse, http_res, http_res_text
            )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStreamAsync(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.CreateChatCompletionResponseBody
                ).data,
                sentinel="[DONE]",
                client_ref=self,
            )
        if utils.match_response(http_res, "400", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res, http_res_text
            )
            raise errors.BadRequestError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "401", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.AuthenticationErrorData, http_res, http_res_text
            )
            raise errors.AuthenticationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "403", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.PermissionDeniedErrorData, http_res, http_res_text
            )
            raise errors.PermissionDeniedError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res, http_res_text
            )
            raise errors.UnprocessableEntityError(
                response_data, http_res, http_res_text
            )
        if utils.match_response(http_res, "429", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.RateLimitErrorData, http_res, http_res_text
            )
            raise errors.RateLimitError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "500", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res, http_res_text
            )
            raise errors.InternalServerError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "503", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res, http_res_text
            )
            raise errors.ServiceUnavailableError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)

        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.R9SDefaultError(
            "Unexpected response received", http_res, http_res_text
        )
