"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from enum import Enum
from r9s import errors, models, utils
from r9s._hooks import HookContext
from r9s.types import OptionalNullable, UNSET
from r9s.utils import eventstreaming
from r9s.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Dict, List, Literal, Mapping, Optional, Union, overload


class CreateAcceptEnum(str, Enum):
    APPLICATION_JSON = "application/json"
    TEXT_EVENT_STREAM = "text/event-stream"


class Messages(BaseSDK):
    @overload
    def create(
        self,
        *,
        model: str,
        messages: Union[
            List[models.AnthropicMessageMessage],
            List[models.AnthropicMessageMessageTypedDict],
        ],
        system: Optional[str] = None,
        max_tokens: Optional[int] = None,
        stop_sequences: Optional[List[str]] = None,
        stream: Union[Literal[False], None] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[
            Union[List[models.AnthropicTool], List[models.AnthropicToolTypedDict]]
        ] = None,
        tool_choice: Optional[
            Union[
                models.AnthropicMessageRequestToolChoice,
                models.AnthropicMessageRequestToolChoiceTypedDict,
            ]
        ] = None,
        metadata: Optional[Dict[str, Any]] = None,
        thinking: Optional[Union[models.Thinking, models.ThinkingTypedDict]] = None,
        service_tier: Optional[models.AnthropicMessageRequestServiceTier] = "auto",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AnthropicMessageResponse:
        r"""Create message (Claude native API)

        Create a message using Anthropic Claude's native API format, supports streaming

        :param model: Claude model name
        :param messages: Messages list, first message must be a user message
        :param system: System prompt
        :param max_tokens: Maximum number of output tokens (optional).
            If not provided, the relay service or API may use a default value.
            Different models have different maximum values.

        :param stop_sequences: Stop sequences
        :param stream:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter. Only sample from the top K options for each subsequent token.
        :param tools:
        :param tool_choice:
        :param metadata: An object describing metadata about the request. Can be used for tracking, identification, or filtering purposes.
            Common use cases: user_id, session_id, request_id, etc.

        :param thinking: Configuration for extended thinking (Claude 3.7+). When enabled, the model will spend more time thinking before responding.

        :param service_tier: Service tier for request processing:
            - auto: Automatically select between standard and priority capacity
            - standard_only: Only use standard capacity (may have longer wait times during high load)

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    @overload
    def create(
        self,
        *,
        model: str,
        messages: Union[
            List[models.AnthropicMessageMessage],
            List[models.AnthropicMessageMessageTypedDict],
        ],
        system: Optional[str] = None,
        max_tokens: Optional[int] = None,
        stop_sequences: Optional[List[str]] = None,
        stream: Literal[True],
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[
            Union[List[models.AnthropicTool], List[models.AnthropicToolTypedDict]]
        ] = None,
        tool_choice: Optional[
            Union[
                models.AnthropicMessageRequestToolChoice,
                models.AnthropicMessageRequestToolChoiceTypedDict,
            ]
        ] = None,
        metadata: Optional[Dict[str, Any]] = None,
        thinking: Optional[Union[models.Thinking, models.ThinkingTypedDict]] = None,
        service_tier: Optional[models.AnthropicMessageRequestServiceTier] = "auto",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStream[models.AnthropicStreamEvent]:
        r"""Create message (Claude native API)

        Create a message using Anthropic Claude's native API format, supports streaming

        :param model: Claude model name
        :param messages: Messages list, first message must be a user message
        :param system: System prompt
        :param max_tokens: Maximum number of output tokens (optional).
            If not provided, the relay service or API may use a default value.
            Different models have different maximum values.

        :param stop_sequences: Stop sequences
        :param stream:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter. Only sample from the top K options for each subsequent token.
        :param tools:
        :param tool_choice:
        :param metadata: An object describing metadata about the request. Can be used for tracking, identification, or filtering purposes.
            Common use cases: user_id, session_id, request_id, etc.

        :param thinking: Configuration for extended thinking (Claude 3.7+). When enabled, the model will spend more time thinking before responding.

        :param service_tier: Service tier for request processing:
            - auto: Automatically select between standard and priority capacity
            - standard_only: Only use standard capacity (may have longer wait times during high load)

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    def create(
        self,
        *,
        model: str,
        messages: Union[
            List[models.AnthropicMessageMessage],
            List[models.AnthropicMessageMessageTypedDict],
        ],
        system: Optional[str] = None,
        max_tokens: Optional[int] = None,
        stop_sequences: Optional[List[str]] = None,
        stream: Optional[bool] = False,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[
            Union[List[models.AnthropicTool], List[models.AnthropicToolTypedDict]]
        ] = None,
        tool_choice: Optional[
            Union[
                models.AnthropicMessageRequestToolChoice,
                models.AnthropicMessageRequestToolChoiceTypedDict,
            ]
        ] = None,
        metadata: Optional[Dict[str, Any]] = None,
        thinking: Optional[Union[models.Thinking, models.ThinkingTypedDict]] = None,
        service_tier: Optional[models.AnthropicMessageRequestServiceTier] = "auto",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateMessageResponse:
        r"""Create message (Claude native API)

        Create a message using Anthropic Claude's native API format, supports streaming

        :param model: Claude model name
        :param messages: Messages list, first message must be a user message
        :param system: System prompt
        :param max_tokens: Maximum number of output tokens (optional).
            If not provided, the relay service or API may use a default value.
            Different models have different maximum values.

        :param stop_sequences: Stop sequences
        :param stream:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter. Only sample from the top K options for each subsequent token.
        :param tools:
        :param tool_choice:
        :param metadata: An object describing metadata about the request. Can be used for tracking, identification, or filtering purposes.
            Common use cases: user_id, session_id, request_id, etc.

        :param thinking: Configuration for extended thinking (Claude 3.7+). When enabled, the model will spend more time thinking before responding.

        :param service_tier: Service tier for request processing:
            - auto: Automatically select between standard and priority capacity
            - standard_only: Only use standard capacity (may have longer wait times during high load)

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.AnthropicMessageRequest(
            model=model,
            messages=utils.get_pydantic_model(
                messages, List[models.AnthropicMessageMessage]
            ),
            system=system,
            max_tokens=max_tokens,
            stop_sequences=stop_sequences,
            stream=stream,
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            tools=utils.get_pydantic_model(tools, Optional[List[models.AnthropicTool]]),
            tool_choice=utils.get_pydantic_model(
                tool_choice, Optional[models.AnthropicMessageRequestToolChoice]
            ),
            metadata=metadata,
            thinking=utils.get_pydantic_model(thinking, Optional[models.Thinking]),
            service_tier=service_tier,
        )

        req = self._build_request(
            method="POST",
            path="/messages",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream" if stream else "application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.AnthropicMessageRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createMessage",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            return unmarshal_json_response(
                models.AnthropicMessageResponse, http_res, http_res_text
            )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStream(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.CreateMessageResponseBody
                ).data,
                client_ref=self,
            )
        if utils.match_response(http_res, "400", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res, http_res_text
            )
            raise errors.BadRequestError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "401", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.AuthenticationErrorData, http_res, http_res_text
            )
            raise errors.AuthenticationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "403", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.PermissionDeniedErrorData, http_res, http_res_text
            )
            raise errors.PermissionDeniedError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res, http_res_text
            )
            raise errors.UnprocessableEntityError(
                response_data, http_res, http_res_text
            )
        if utils.match_response(http_res, "429", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.RateLimitErrorData, http_res, http_res_text
            )
            raise errors.RateLimitError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "500", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res, http_res_text
            )
            raise errors.InternalServerError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "503", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res, http_res_text
            )
            raise errors.ServiceUnavailableError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)

        http_res_text = utils.stream_to_text(http_res)
        raise errors.R9SDefaultError(
            "Unexpected response received", http_res, http_res_text
        )

    @overload
    async def create_async(
        self,
        *,
        model: str,
        messages: Union[
            List[models.AnthropicMessageMessage],
            List[models.AnthropicMessageMessageTypedDict],
        ],
        system: Optional[str] = None,
        max_tokens: Optional[int] = None,
        stop_sequences: Optional[List[str]] = None,
        stream: Union[Literal[False], None] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[
            Union[List[models.AnthropicTool], List[models.AnthropicToolTypedDict]]
        ] = None,
        tool_choice: Optional[
            Union[
                models.AnthropicMessageRequestToolChoice,
                models.AnthropicMessageRequestToolChoiceTypedDict,
            ]
        ] = None,
        metadata: Optional[Dict[str, Any]] = None,
        thinking: Optional[Union[models.Thinking, models.ThinkingTypedDict]] = None,
        service_tier: Optional[models.AnthropicMessageRequestServiceTier] = "auto",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AnthropicMessageResponse:
        r"""Create message (Claude native API)

        Create a message using Anthropic Claude's native API format, supports streaming

        :param model: Claude model name
        :param messages: Messages list, first message must be a user message
        :param system: System prompt
        :param max_tokens: Maximum number of output tokens (optional).
            If not provided, the relay service or API may use a default value.
            Different models have different maximum values.

        :param stop_sequences: Stop sequences
        :param stream:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter. Only sample from the top K options for each subsequent token.
        :param tools:
        :param tool_choice:
        :param metadata: An object describing metadata about the request. Can be used for tracking, identification, or filtering purposes.
            Common use cases: user_id, session_id, request_id, etc.

        :param thinking: Configuration for extended thinking (Claude 3.7+). When enabled, the model will spend more time thinking before responding.

        :param service_tier: Service tier for request processing:
            - auto: Automatically select between standard and priority capacity
            - standard_only: Only use standard capacity (may have longer wait times during high load)

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    @overload
    async def create_async(
        self,
        *,
        model: str,
        messages: Union[
            List[models.AnthropicMessageMessage],
            List[models.AnthropicMessageMessageTypedDict],
        ],
        system: Optional[str] = None,
        max_tokens: Optional[int] = None,
        stop_sequences: Optional[List[str]] = None,
        stream: Literal[True],
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[
            Union[List[models.AnthropicTool], List[models.AnthropicToolTypedDict]]
        ] = None,
        tool_choice: Optional[
            Union[
                models.AnthropicMessageRequestToolChoice,
                models.AnthropicMessageRequestToolChoiceTypedDict,
            ]
        ] = None,
        metadata: Optional[Dict[str, Any]] = None,
        thinking: Optional[Union[models.Thinking, models.ThinkingTypedDict]] = None,
        service_tier: Optional[models.AnthropicMessageRequestServiceTier] = "auto",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStreamAsync[models.AnthropicStreamEvent]:
        r"""Create message (Claude native API)

        Create a message using Anthropic Claude's native API format, supports streaming

        :param model: Claude model name
        :param messages: Messages list, first message must be a user message
        :param system: System prompt
        :param max_tokens: Maximum number of output tokens (optional).
            If not provided, the relay service or API may use a default value.
            Different models have different maximum values.

        :param stop_sequences: Stop sequences
        :param stream:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter. Only sample from the top K options for each subsequent token.
        :param tools:
        :param tool_choice:
        :param metadata: An object describing metadata about the request. Can be used for tracking, identification, or filtering purposes.
            Common use cases: user_id, session_id, request_id, etc.

        :param thinking: Configuration for extended thinking (Claude 3.7+). When enabled, the model will spend more time thinking before responding.

        :param service_tier: Service tier for request processing:
            - auto: Automatically select between standard and priority capacity
            - standard_only: Only use standard capacity (may have longer wait times during high load)

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """

    async def create_async(
        self,
        *,
        model: str,
        messages: Union[
            List[models.AnthropicMessageMessage],
            List[models.AnthropicMessageMessageTypedDict],
        ],
        system: Optional[str] = None,
        max_tokens: Optional[int] = None,
        stop_sequences: Optional[List[str]] = None,
        stream: Optional[bool] = False,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        tools: Optional[
            Union[List[models.AnthropicTool], List[models.AnthropicToolTypedDict]]
        ] = None,
        tool_choice: Optional[
            Union[
                models.AnthropicMessageRequestToolChoice,
                models.AnthropicMessageRequestToolChoiceTypedDict,
            ]
        ] = None,
        metadata: Optional[Dict[str, Any]] = None,
        thinking: Optional[Union[models.Thinking, models.ThinkingTypedDict]] = None,
        service_tier: Optional[models.AnthropicMessageRequestServiceTier] = "auto",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateMessageResponse:
        r"""Create message (Claude native API)

        Create a message using Anthropic Claude's native API format, supports streaming

        :param model: Claude model name
        :param messages: Messages list, first message must be a user message
        :param system: System prompt
        :param max_tokens: Maximum number of output tokens (optional).
            If not provided, the relay service or API may use a default value.
            Different models have different maximum values.

        :param stop_sequences: Stop sequences
        :param stream:
        :param temperature:
        :param top_p:
        :param top_k: Top-k sampling parameter. Only sample from the top K options for each subsequent token.
        :param tools:
        :param tool_choice:
        :param metadata: An object describing metadata about the request. Can be used for tracking, identification, or filtering purposes.
            Common use cases: user_id, session_id, request_id, etc.

        :param thinking: Configuration for extended thinking (Claude 3.7+). When enabled, the model will spend more time thinking before responding.

        :param service_tier: Service tier for request processing:
            - auto: Automatically select between standard and priority capacity
            - standard_only: Only use standard capacity (may have longer wait times during high load)

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.AnthropicMessageRequest(
            model=model,
            messages=utils.get_pydantic_model(
                messages, List[models.AnthropicMessageMessage]
            ),
            system=system,
            max_tokens=max_tokens,
            stop_sequences=stop_sequences,
            stream=stream,
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            tools=utils.get_pydantic_model(tools, Optional[List[models.AnthropicTool]]),
            tool_choice=utils.get_pydantic_model(
                tool_choice, Optional[models.AnthropicMessageRequestToolChoice]
            ),
            metadata=metadata,
            thinking=utils.get_pydantic_model(thinking, Optional[models.Thinking]),
            service_tier=service_tier,
        )

        req = self._build_request_async(
            method="POST",
            path="/messages",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream" if stream else "application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.AnthropicMessageRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createMessage",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            return unmarshal_json_response(
                models.AnthropicMessageResponse, http_res, http_res_text
            )
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStreamAsync(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.CreateMessageResponseBody
                ).data,
                client_ref=self,
            )
        if utils.match_response(http_res, "400", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res, http_res_text
            )
            raise errors.BadRequestError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "401", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.AuthenticationErrorData, http_res, http_res_text
            )
            raise errors.AuthenticationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "403", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.PermissionDeniedErrorData, http_res, http_res_text
            )
            raise errors.PermissionDeniedError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res, http_res_text
            )
            raise errors.UnprocessableEntityError(
                response_data, http_res, http_res_text
            )
        if utils.match_response(http_res, "429", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.RateLimitErrorData, http_res, http_res_text
            )
            raise errors.RateLimitError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "500", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res, http_res_text
            )
            raise errors.InternalServerError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "503", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res, http_res_text
            )
            raise errors.ServiceUnavailableError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)

        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.R9SDefaultError(
            "Unexpected response received", http_res, http_res_text
        )
