"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .anthropicinputschema import AnthropicInputSchema, AnthropicInputSchemaTypedDict
from r9s.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AnthropicToolTypedDict(TypedDict):
    name: str
    input_schema: AnthropicInputSchemaTypedDict
    description: NotRequired[str]


class AnthropicTool(BaseModel):
    name: str

    input_schema: AnthropicInputSchema

    description: Optional[str] = None
