"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .moderationcategories import ModerationCategories, ModerationCategoriesTypedDict
from .moderationcategoryscores import (
    ModerationCategoryScores,
    ModerationCategoryScoresTypedDict,
)
from r9s.types import BaseModel
from typing_extensions import TypedDict


class ModerationResultTypedDict(TypedDict):
    flagged: bool
    categories: ModerationCategoriesTypedDict
    category_scores: ModerationCategoryScoresTypedDict


class ModerationResult(BaseModel):
    flagged: bool

    categories: ModerationCategories

    category_scores: ModerationCategoryScores
