"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AnthropicThinkingContentTypedDict(TypedDict):
    thinking: str
    r"""The model's thinking process/reasoning"""
    type: Literal["thinking"]
    r"""Extended thinking output content"""
    signature: NotRequired[str]
    r"""Cryptographic signature for thinking content verification"""


class AnthropicThinkingContent(BaseModel):
    thinking: str
    r"""The model's thinking process/reasoning"""

    TYPE: Annotated[
        Annotated[Literal["thinking"], AfterValidator(validate_const("thinking"))],
        pydantic.Field(alias="type"),
    ] = "thinking"
    r"""Extended thinking output content"""

    signature: Optional[str] = None
    r"""Cryptographic signature for thinking content verification"""
