"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EditRequestTypedDict(TypedDict):
    model: str
    r"""Model name"""
    instruction: str
    r"""Edit instruction"""
    input: NotRequired[str]
    r"""Input text to edit"""
    n: NotRequired[int]
    temperature: NotRequired[float]
    top_p: NotRequired[float]


class EditRequest(BaseModel):
    model: str
    r"""Model name"""

    instruction: str
    r"""Edit instruction"""

    input: Optional[str] = ""
    r"""Input text to edit"""

    n: Optional[int] = 1

    temperature: Optional[float] = 1

    top_p: Optional[float] = 1
