"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PropertiesTypedDict(TypedDict):
    pass


class Properties(BaseModel):
    pass


class AnthropicInputSchemaTypedDict(TypedDict):
    type: Literal["object"]
    properties: NotRequired[PropertiesTypedDict]
    required: NotRequired[List[str]]


class AnthropicInputSchema(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["object"], AfterValidator(validate_const("object"))],
        pydantic.Field(alias="type"),
    ] = "object"

    properties: Optional[Properties] = None

    required: Optional[List[str]] = None
