"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel, Nullable, UNSET_SENTINEL
from r9s.utils import validate_const
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class AnthropicMessageStartContentTypedDict(TypedDict):
    pass


class AnthropicMessageStartContent(BaseModel):
    pass


class AnthropicMessageStartUsageTypedDict(TypedDict):
    input_tokens: int
    output_tokens: int


class AnthropicMessageStartUsage(BaseModel):
    input_tokens: int

    output_tokens: int


class AnthropicMessageStartMessageTypedDict(TypedDict):
    id: str
    content: List[AnthropicMessageStartContentTypedDict]
    model: str
    stop_reason: Nullable[str]
    stop_sequence: Nullable[str]
    usage: AnthropicMessageStartUsageTypedDict
    type: Literal["message"]
    role: Literal["assistant"]


class AnthropicMessageStartMessage(BaseModel):
    id: str

    content: List[AnthropicMessageStartContent]

    model: str

    stop_reason: Nullable[str]

    stop_sequence: Nullable[str]

    usage: AnthropicMessageStartUsage

    TYPE: Annotated[
        Annotated[Literal["message"], AfterValidator(validate_const("message"))],
        pydantic.Field(alias="type"),
    ] = "message"

    ROLE: Annotated[
        Annotated[Literal["assistant"], AfterValidator(validate_const("assistant"))],
        pydantic.Field(alias="role"),
    ] = "assistant"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["stop_reason", "stop_sequence"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class AnthropicMessageStartTypedDict(TypedDict):
    message: AnthropicMessageStartMessageTypedDict
    type: Literal["message_start"]


class AnthropicMessageStart(BaseModel):
    message: AnthropicMessageStartMessage

    TYPE: Annotated[
        Annotated[
            Literal["message_start"], AfterValidator(validate_const("message_start"))
        ],
        pydantic.Field(alias="type"),
    ] = "message_start"
