"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FunctionCallTypedDict(TypedDict):
    name: str
    arguments: NotRequired[str]


class FunctionCall(BaseModel):
    name: str

    arguments: Optional[str] = None
