"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ImageObjectTypedDict(TypedDict):
    url: NotRequired[str]
    r"""Image URL"""
    b64_json: NotRequired[str]
    r"""Base64-encoded JSON"""
    revised_prompt: NotRequired[str]
    r"""Revised prompt"""


class ImageObject(BaseModel):
    url: Optional[str] = None
    r"""Image URL"""

    b64_json: Optional[str] = None
    r"""Base64-encoded JSON"""

    revised_prompt: Optional[str] = None
    r"""Revised prompt"""
