"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .audiotranslationresponse import (
    AudioTranslationResponse,
    AudioTranslationResponseTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CreateAudioTranslationResponseTypedDict = TypeAliasType(
    "CreateAudioTranslationResponseTypedDict",
    Union[AudioTranslationResponseTypedDict, str],
)


CreateAudioTranslationResponse = TypeAliasType(
    "CreateAudioTranslationResponse", Union[AudioTranslationResponse, str]
)
