"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .engineembeddingrequest import (
    EngineEmbeddingRequest,
    EngineEmbeddingRequestTypedDict,
)
from r9s.types import BaseModel
from r9s.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CreateEngineEmbeddingRequestTypedDict(TypedDict):
    model: str
    r"""Engine model name"""
    engine_embedding_request: EngineEmbeddingRequestTypedDict


class CreateEngineEmbeddingRequest(BaseModel):
    model: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Engine model name"""

    engine_embedding_request: Annotated[
        EngineEmbeddingRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
