"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from r9s.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateProxyRequestRequestTypedDict(TypedDict):
    channelid: str
    r"""Channel ID"""
    target: str
    r"""Target path"""
    request_body: NotRequired[Dict[str, Any]]


class CreateProxyRequestRequest(BaseModel):
    channelid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Channel ID"""

    target: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Target path"""

    request_body: Annotated[
        Optional[Dict[str, Any]],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None
