"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from r9s.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class JSONSchemaTypedDict(TypedDict):
    name: NotRequired[str]
    description: NotRequired[str]
    schema_: NotRequired[Dict[str, Any]]


class JSONSchema(BaseModel):
    name: Optional[str] = None

    description: Optional[str] = None

    schema_: Annotated[Optional[Dict[str, Any]], pydantic.Field(alias="schema")] = None
