"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .model import Model, ModelTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class ModelListResponseTypedDict(TypedDict):
    data: List[ModelTypedDict]
    object: Literal["list"]


class ModelListResponse(BaseModel):
    data: List[Model]

    OBJECT: Annotated[
        Annotated[Literal["list"], AfterValidator(validate_const("list"))],
        pydantic.Field(alias="object"),
    ] = "list"
