"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AudioTranslationResponseTypedDict(TypedDict):
    text: str
    r"""Translated English text"""
    language: NotRequired[str]
    r"""Source language"""
    duration: NotRequired[float]
    r"""Audio duration (seconds)"""


class AudioTranslationResponse(BaseModel):
    text: str
    r"""Translated English text"""

    language: Optional[str] = None
    r"""Source language"""

    duration: Optional[float] = None
    r"""Audio duration (seconds)"""
