"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from pydantic import model_serializer
from r9s.errors import R9SError
from r9s.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


class ErrorTypedDict(TypedDict):
    message: str
    r"""Error message"""
    type: str
    r"""Error type"""
    code: NotRequired[Nullable[str]]
    r"""Error code"""
    param: NotRequired[str]
    r"""Related parameter"""


class Error(BaseModel):
    message: str
    r"""Error message"""

    type: str
    r"""Error type"""

    code: OptionalNullable[str] = UNSET
    r"""Error code"""

    param: Optional[str] = None
    r"""Related parameter"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["code", "param"]
        nullable_fields = ["code"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


Status = Literal["401",]


class AuthenticationErrorData(BaseModel):
    error: Error

    status: Optional[Status] = None


@dataclass(unsafe_hash=True)
class AuthenticationError(R9SError):
    data: AuthenticationErrorData = field(hash=False)

    def __init__(
        self,
        data: AuthenticationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
