"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .embeddingobject import EmbeddingObject, EmbeddingObjectTypedDict
from .usage import Usage, UsageTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class EmbeddingResponseTypedDict(TypedDict):
    data: List[EmbeddingObjectTypedDict]
    model: str
    usage: UsageTypedDict
    object: Literal["list"]


class EmbeddingResponse(BaseModel):
    data: List[EmbeddingObject]

    model: str

    usage: Usage

    OBJECT: Annotated[
        Annotated[Literal["list"], AfterValidator(validate_const("list"))],
        pydantic.Field(alias="object"),
    ] = "list"
