"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .anthropicimagesource import AnthropicImageSource, AnthropicImageSourceTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import Literal
from typing_extensions import Annotated, TypedDict


class AnthropicImageContentTypedDict(TypedDict):
    source: AnthropicImageSourceTypedDict
    type: Literal["image"]


class AnthropicImageContent(BaseModel):
    source: AnthropicImageSource

    TYPE: Annotated[
        Annotated[Literal["image"], AfterValidator(validate_const("image"))],
        pydantic.Field(alias="type"),
    ] = "image"
