"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel
from r9s.utils import validate_const
from typing import Literal
from typing_extensions import Annotated, TypedDict


class AnthropicStreamMessageStopTypedDict(TypedDict):
    type: Literal["message_stop"]


class AnthropicStreamMessageStop(BaseModel):
    TYPE: Annotated[
        Annotated[
            Literal["message_stop"], AfterValidator(validate_const("message_stop"))
        ],
        pydantic.Field(alias="type"),
    ] = "message_stop"
