"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .moderationresult import ModerationResult, ModerationResultTypedDict
from r9s.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ModerationResponseTypedDict(TypedDict):
    id: str
    model: str
    results: List[ModerationResultTypedDict]


class ModerationResponse(BaseModel):
    id: str

    model: str

    results: List[ModerationResult]
