"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .anthropicdocumentcontent import (
    AnthropicDocumentContent,
    AnthropicDocumentContentTypedDict,
)
from .anthropicimagecontent import AnthropicImageContent, AnthropicImageContentTypedDict
from .anthropictextcontent import AnthropicTextContent, AnthropicTextContentTypedDict
from .anthropicthinkingcontent import (
    AnthropicThinkingContent,
    AnthropicThinkingContentTypedDict,
)
from .anthropictoolcontent import AnthropicToolContent, AnthropicToolContentTypedDict
from typing import Union
from typing_extensions import TypeAliasType


AnthropicContentTypedDict = TypeAliasType(
    "AnthropicContentTypedDict",
    Union[
        AnthropicTextContentTypedDict,
        AnthropicImageContentTypedDict,
        AnthropicDocumentContentTypedDict,
        AnthropicThinkingContentTypedDict,
        AnthropicToolContentTypedDict,
    ],
)


AnthropicContent = TypeAliasType(
    "AnthropicContent",
    Union[
        AnthropicTextContent,
        AnthropicImageContent,
        AnthropicDocumentContent,
        AnthropicThinkingContent,
        AnthropicToolContent,
    ],
)
