"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .audiotranscriptionresponse import (
    AudioTranscriptionResponse,
    AudioTranscriptionResponseTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CreateAudioTranscriptionResponseTypedDict = TypeAliasType(
    "CreateAudioTranscriptionResponseTypedDict",
    Union[AudioTranscriptionResponseTypedDict, str, str, str],
)


CreateAudioTranscriptionResponse = TypeAliasType(
    "CreateAudioTranscriptionResponse", Union[AudioTranscriptionResponse, str, str, str]
)
