"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .functioncall import FunctionCall, FunctionCallTypedDict
from r9s.types import BaseModel
from typing_extensions import TypedDict


class ToolCallTypedDict(TypedDict):
    id: str
    type: str
    function: FunctionCallTypedDict


class ToolCall(BaseModel):
    id: str

    type: str

    function: FunctionCall
