"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from r9s.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from r9s.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AnthropicMessageDeltaDeltaTypedDict(TypedDict):
    stop_reason: NotRequired[Nullable[str]]


class AnthropicMessageDeltaDelta(BaseModel):
    stop_reason: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["stop_reason"]
        nullable_fields = ["stop_reason"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class AnthropicMessageDeltaUsageTypedDict(TypedDict):
    output_tokens: NotRequired[int]


class AnthropicMessageDeltaUsage(BaseModel):
    output_tokens: Optional[int] = None


class AnthropicMessageDeltaTypedDict(TypedDict):
    delta: AnthropicMessageDeltaDeltaTypedDict
    usage: AnthropicMessageDeltaUsageTypedDict
    type: Literal["message_delta"]


class AnthropicMessageDelta(BaseModel):
    delta: AnthropicMessageDeltaDelta

    usage: AnthropicMessageDeltaUsage

    TYPE: Annotated[
        Annotated[
            Literal["message_delta"], AfterValidator(validate_const("message_delta"))
        ],
        pydantic.Field(alias="type"),
    ] = "message_delta"
