"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from r9s.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


Detail = Literal[
    "auto",
    "low",
    "high",
]


class ImageURLTypedDict(TypedDict):
    url: str
    detail: NotRequired[Detail]


class ImageURL(BaseModel):
    url: str

    detail: Optional[Detail] = None
