"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .imageurl import ImageURL, ImageURLTypedDict
from r9s.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


Type = Literal[
    "text",
    "image_url",
]


class MessageContentTypedDict(TypedDict):
    type: Type
    text: NotRequired[str]
    image_url: NotRequired[ImageURLTypedDict]


class MessageContent(BaseModel):
    type: Type

    text: Optional[str] = None

    image_url: Optional[ImageURL] = None
