"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from r9s import errors, models, utils
from r9s._hooks import HookContext
from r9s.types import OptionalNullable, UNSET
from r9s.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional, Union


class Search(BaseSDK):
    def create(
        self,
        *,
        extra: Union[models.Extra, models.ExtraTypedDict],
        engine: Optional[models.Engine] = "exa",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SearchResponse:
        r"""Create search

        Execute web search queries using specified search engine. Supports three search engines:Exa (AI-native search, default), Tavily (with AI summary), Google (custom search)

        :param extra: Engine-specific parameters. Different engines support different parameters:

            **Exa engine parameters:**
            - query (string, required): Search query
            - num (integer): Number of results to return, default 10
            - contents.text (boolean): Whether to return full text content

            **Tavily engine parameters:**
            - query (string, required): Search query
            - max_results (integer): Maximum number of results, default 10
            - search_depth (string): Search depth, \"basic\" or \"advanced\", default \"basic\"
            - include_answer (boolean): Whether to include AI-generated summary answer, default true

            **Google engine parameters:**
            - query (string, required): Search query
            - num (integer): Number of results (1-10), default 10
            - start (integer): Starting position (pagination), default 1
            - safe (string): Safe search, \"active\" or \"off\", default \"active\"

        :param engine: Search engine name (optional, defaults to exa)
            - exa: AI-native search engine, suitable for semantic search
            - tavily: AI search API, supports deep search and summary answers
            - google: Google custom search, most comprehensive index

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.SearchRequest(
            engine=engine,
            extra=utils.get_pydantic_model(extra, models.Extra),
        )

        req = self._build_request(
            method="POST",
            path="/search",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SearchRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createSearch",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "500", "503", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.SearchResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.AuthenticationErrorData, http_res
            )
            raise errors.AuthenticationError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PermissionDeniedErrorData, http_res
            )
            raise errors.PermissionDeniedError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)

        raise errors.R9SDefaultError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        extra: Union[models.Extra, models.ExtraTypedDict],
        engine: Optional[models.Engine] = "exa",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SearchResponse:
        r"""Create search

        Execute web search queries using specified search engine. Supports three search engines:Exa (AI-native search, default), Tavily (with AI summary), Google (custom search)

        :param extra: Engine-specific parameters. Different engines support different parameters:

            **Exa engine parameters:**
            - query (string, required): Search query
            - num (integer): Number of results to return, default 10
            - contents.text (boolean): Whether to return full text content

            **Tavily engine parameters:**
            - query (string, required): Search query
            - max_results (integer): Maximum number of results, default 10
            - search_depth (string): Search depth, \"basic\" or \"advanced\", default \"basic\"
            - include_answer (boolean): Whether to include AI-generated summary answer, default true

            **Google engine parameters:**
            - query (string, required): Search query
            - num (integer): Number of results (1-10), default 10
            - start (integer): Starting position (pagination), default 1
            - safe (string): Safe search, \"active\" or \"off\", default \"active\"

        :param engine: Search engine name (optional, defaults to exa)
            - exa: AI-native search engine, suitable for semantic search
            - tavily: AI search API, supports deep search and summary answers
            - google: Google custom search, most comprehensive index

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.SearchRequest(
            engine=engine,
            extra=utils.get_pydantic_model(extra, models.Extra),
        )

        req = self._build_request_async(
            method="POST",
            path="/search",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.SearchRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createSearch",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "4XX", "500", "503", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.SearchResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.AuthenticationErrorData, http_res
            )
            raise errors.AuthenticationError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PermissionDeniedErrorData, http_res
            )
            raise errors.PermissionDeniedError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.R9SDefaultError("API error occurred", http_res, http_res_text)

        raise errors.R9SDefaultError("Unexpected response received", http_res)
